BEGIN TRANSACTION;

 drop table if exists Article ;
 drop table if exists Stock ;
 drop table if exists Inventory ;
 drop table if exists Species ;
 drop table if exists Ingredient ;
 drop table if exists Creature ;
 drop table if exists Zone ;
 drop table if exists Phenomenon ;
 drop table if exists Activity ;
 drop table if exists ContainerType ;
 drop table if exists Recipe ;
 drop table if exists LivingCondition ;
 drop table if exists Market ;
 drop table if exists Field ;
 drop table if exists Image ;
 drop table if exists Parameter ;

-- Article
create table Article (
  id                        varchar(32) not null,
  volume                    float not null,
  shelf_time                int not null,
  value_for_obj_fun         float,
  image_id                  varchar(32),
  constraint pk_Article primary key (id)
  
) ;

-- Stock
create table Stock (
  id                        varchar(32) not null,
  capacity                  float not null,
  change_shelf_time int,
  constraint pk_Stock primary key (id)
) ;

-- Inventory
create table Inventory (
  stock_id                 constraint fk_Stock references Stock (id) ,
  article_id                constraint fk_Article references Article (id),
  shelf_time                int not null,
  quant                     float,
  constraint pk_Inventory primary key (stock_id,article_id,shelf_time)
  ) ;

-- Species
create table Species (
  id                        varchar2(32) not null,
  activities_count          int,
  crossover_probability     float,
  mutation_probability      float,
  crossover_type            varchar(32),
  initial_stock_id          varchar(32),
  constraint pk_Species primary key (id)
) ;

-- Ingredient
create table Ingredient (
  recipe_id                 constraint fk_Recipe references Recipe (id) ,
  article_id                constraint fk_Article references Article (id) ,
  article_quant             float,
  article_container         varchar2(32) not null,
  article_role              varchar(32) not null,
  constraint pk_Ingredient primary key (recipe_id,article_id,article_container,article_role)
) ;

-- Creature
create table Creature (
  id                        varchar(32) not null,
  species_id        constraint fk_Species references Species (id) ,
  age                       int,
  backpack_id       constraint fk_Backpack references Stock (id) ,
  position_x                int,
  position_y                int,
  image_id                  varchar(32),
  constraint pk_Creature primary key (id)
) ;

-- Zone
create table Zone (
  id                        varchar(32) not null,
  coordinate_x              int not null,
  coordinate_y              int not null,
  size_x                    int,
  size_y                    int,
  image_id                  varchar(32),
  constraint pk_Zone primary key (id)
) ;

-- Phenomenon
create table Phenomenon (
  zone_id                   varchar(32) not null,
  definition_id          constraint fk_Recipe references Recipe (id) ,
  init_position_y           int not null,
  init_position_x           int not null,
  frequency                 int,
  max_occurrence_at_moment  int,
  range                     int,
  constraint pk_Phenomenon primary key (zone_id,definition_id,init_position_y,init_position_x)
) ;

-- Activity
create table Activity (
  creature_id            constraint fk_Creature references Creature (id) ,
  lp                        int not null,
  definition_id            constraint fk_Recipe references Recipe (id) ,
  constraint pk_Activity primary key (creature_id,lp)
) ;

-- ContainerType
create table ContainerType (
  id                        int not null,
  description               varchar(128),
  constraint pk_ContainerType primary key (id)
) ;

-- Recipe
create table Recipe (
  id                        varchar(32),
  owner_id                  constraint fk_Owner references ContainerType (id) ,
  position_x_influence      int,
  position_y_influence      int,
    constraint pk_Recipe primary key (id)
) ;

-- LivingCondition
create table LivingCondition (
  zone_id                 constraint fk_Zone references Zone (id) ,
  species_id            constraint fk_Species references Species (id) ,
  creatures_limit           int,
  creatures_limit_grid_size int,
  mate_grid_size            int,
  constraint pk_LivingCondition primary key (zone_id,species_id)
) ;

-- Market
create table Market (
  store_id                constraint fk_Store references Stock (id) ,
  position_x                int,
  position_y                int,
  size_x                    int,
  size_y                    int,
  constraint pk_Market primary key (store_id)
) ;

-- Field
create table Field (
  resource_id              constraint fk_Resource references Stock (id) ,
  position_x                int,
  position_y                int,
  constraint pk_Field primary key (resource_id)
) ;

-- Image
create table Image (
  id                        varchar(32) not null,
  path                      varchar(256),
  constraint pk_Image primary key (id)
) ;

-- Parameter
create table Parameter (
  id                        varchar(256) not null,
  value                     varchar(256),
  constraint pk_Parameter primary key (id)
) ;

insert into ContainerType (id, description)
values ("creature", "Source or destination is creature");

insert into ContainerType (id, description)
values ("field", "Source or destination is field");

insert into ContainerType (id, description)
values ("market", "Source or destination is market");


insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('water',1.0,1000*356,0.5,'water');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('soil',2.0,200*356,0.01,'soil');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('seed_of_grain',0.001,50*356,0.01,'seed_of_grain');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('grain',0.01,1*356,0.1,'grain');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('energy',0.0000001,30,1.0,'energy');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('seed_of_tree',0.001,50*356,0.01,'seed_of_tree');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('wood',3,100*356,0.2,'wood');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('flour',2,3*356,1.0,'flour');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('bread',2,14,2.0,'bread');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('coin',0.01,500*356,1,'coin');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('sheaf',20,3*356,0.8,'sheaf');


insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_up','creature',0,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_up','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right','creature',1,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right_up','creature',1,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right_up','energy',2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left','creature',-1,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left_up','creature',-1,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left_up','energy',2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_down','creature',0,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_down','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right_down','creature',1,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right_down','energy',2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left_down','creature',-1,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left_down','energy',2,'creature','resource');


insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('rainfall','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('rainfall','water',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_grain_appearance','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('seed_of_grain_appearance','seed_of_grain',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('soil_appearance','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('soil_appearance','soil',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_grain_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_grain_picking','seed_of_grain',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_grain_picking','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('sow_grain','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','seed_of_grain',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','seed_of_grain',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('grain_growth','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('grain_growth','grain',1,'field','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','seed_of_grain',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','soil',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','water',1,'field','resource');

insert into stock (id, capacity, change_shelf_time) values ('desert_resources',100000, 1);
insert into stock (id, capacity, change_shelf_time) values ('human_initial_stock',100, 0);
insert into stock (id, capacity, change_shelf_time) values ('dog_initial_stock',100, 0);
insert into stock (id, capacity, change_shelf_time) values ('jack_backpack',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('mary_backpack',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('pluto_backpack',100,  1);
insert into stock (id, capacity, change_shelf_time) values ('adog_backpack',10000, 1);

insert into stock (id, capacity, change_shelf_time) values ('F1x1',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F1x2',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F2x1',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F2x2',10000, 1);

insert into stock (id, capacity, change_shelf_time) values ('F5x5',10000, 1);


insert into stock (id, capacity, change_shelf_time) values ('F7x7',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F7x8',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F8x7',10000, 1);
insert into stock (id, capacity, change_shelf_time) values ('F8x8',10000, 1);


insert into inventory (stock_id, article_id, shelf_time, quant) values ('desert_resources','water',10,10);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('human_initial_stock','energy',1400,1400);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('dog_initial_stock','energy',1400,1400);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('jack_backpack','energy',100,1000);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('pluto_backpack','energy',14,14);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('mary_backpack','energy',100,1000);
insert into inventory (stock_id, article_id, shelf_time, quant) values ('adog_backpack','energy',100,1000);
----
insert into species (id, activities_count, crossover_probability, mutation_probability, crossover_type, initial_stock_id)
 values ('human',16,0.9,0.9,'one_point','human_initial_stock');
insert into species (id, activities_count, crossover_probability, mutation_probability, crossover_type, initial_stock_id) 
values ('dog',8,0.8,0.9,'one_point','dog_initial_stock');


insert into zone (id, coordinate_x, coordinate_y, size_x, size_y, image_id) values ('desert',0,0,10,10,'desert');

insert into field (resource_id, position_x, position_y) values ('F1x1',1,1);
insert into field (resource_id, position_x, position_y) values ('F2x1', 2,1);
insert into field (resource_id, position_x, position_y) values ('F1x2',1,2);
insert into field (resource_id, position_x, position_y) values ('F2x2',2,2);

insert into field (resource_id, position_x, position_y) values ('F5x5',5,5);

insert into field (resource_id, position_x, position_y) values ('F7x7',7,7);
insert into field (resource_id, position_x, position_y) values ('F7x8',7,8);
insert into field (resource_id, position_x, position_y) values ('F8x7',8,7);
insert into field (resource_id, position_x, position_y) values ('F8x8',8,8);

insert into phenomenon (zone_id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('desert',  5, 'rainfall', 10, 1, 1,5);

 insert into phenomenon (zone_id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('desert',  6, 'soil_appearance', 1, 1, 1,1); 

 insert into phenomenon (zone_id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('desert',  10, 'rainfall', 10, 8, 8, 5);

insert into phenomenon (zone_id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('desert',  1, 'seed_of_grain_appearance', 1, 5, 5,1); 

 
 
insert into phenomenon (zone_id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('desert',  1, 'grain_growth', 100, 4,4,5); 


insert into livingcondition (zone_id, species_id, creatures_limit, creatures_limit_grid_size, mate_grid_size) 
values ('desert','human', 40,1000,3);
insert into livingcondition (zone_id, species_id, creatures_limit, creatures_limit_grid_size, mate_grid_size)
values ('desert','dog',40,1000,3);


insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) 
values ('jack','jack_backpack','human',1,1,0,'human');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) 
values ('pluto','pluto_backpack','dog', 4, 4,0,'dog');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) 
values ('mary','mary_backpack','human',1,8,0,'human');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) 
values ('adog','adog_backpack','dog',4,5,0,'dog');

insert into activity (creature_id, lp, definition_id) values ('jack',1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('jack',3,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('jack',4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',5,'step_right');
insert into activity (creature_id, lp, definition_id) values ('jack',6,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('jack',7,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',8,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',9,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',10,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',11,'step_up');
insert into activity (creature_id, lp, definition_id) values ('jack',12,'step_down');
insert into activity (creature_id, lp, definition_id) values ('jack',13,'step_right');
insert into activity (creature_id, lp, definition_id) values ('jack',14,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('jack',15,'step_right');
insert into activity (creature_id, lp, definition_id) values ('jack',16,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('mary',1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('mary',2,'step_up');
insert into activity (creature_id, lp, definition_id) values ('mary',3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('mary',4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('mary',5,'step_down');
insert into activity (creature_id, lp, definition_id) values ('mary',6,'step_up');
insert into activity (creature_id, lp, definition_id) values ('mary',7,'step_down');
insert into activity (creature_id, lp, definition_id) values ('mary',8,'step_right');
insert into activity (creature_id, lp, definition_id) values ('mary',9,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('mary',10,'step_right');
insert into activity (creature_id, lp, definition_id) values ('mary',11,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('mary',12,'step_down');
insert into activity (creature_id, lp, definition_id) values ('mary',13,'step_up');
insert into activity (creature_id, lp, definition_id) values ('mary',14,'step_down');
insert into activity (creature_id, lp, definition_id) values ('mary',15,'step_up');
insert into activity (creature_id, lp, definition_id) values ('mary',16,'step_down');

insert into activity (creature_id, lp, definition_id) values ('adog',1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('adog',2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('adog',3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('adog',4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('adog',5,'step_down');
insert into activity (creature_id, lp, definition_id) values ('adog',6,'step_down');
insert into activity (creature_id, lp, definition_id) values ('adog',7,'step_down');
insert into activity (creature_id, lp, definition_id) values ('adog',8,'step_down');

insert into activity (creature_id, lp, definition_id) values ('pluto',1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('pluto',2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('pluto',3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('pluto',4,'step_right');
insert into activity (creature_id, lp, definition_id) values ('pluto',5,'step_down');
insert into activity (creature_id, lp, definition_id) values ('pluto',6,'step_right');
insert into activity (creature_id, lp, definition_id) values ('pluto',7,'step_right');
insert into activity (creature_id, lp, definition_id) values ('pluto',8,'step_down');

insert into image (id, path) values ('human','./images/human.gif');
insert into image (id, path) values ('dog','./images/dog.gif');
insert into image (id, path) values ('desert','./images/desert.gif');
insert into image (id, path) values ('wood','./images/wood.gif');
insert into image (id, path) values ('water','./images/water.gif');
insert into image (id, path) values ('forest','./images/forest.gif');

insert into image (id, path) values ('soil','./images/soil.gif');
insert into image (id, path) values ('seed_of_grain','./images/seed_of_grain.gif');
insert into image (id, path) values ('grain','./images/grain.gif');
insert into image (id, path) values ('energy','./images/energy.jpg');
insert into image (id, path) values ('seed_of_tree','./images/seed_of_tree.jpg');
insert into image (id, path) values ('flour','./images/flour.jpg');
insert into image (id, path) values ('bread','./images/bread/jpg');
insert into image (id, path) values ('coin','./images/coin.jpg');
insert into image (id, path) values ('sheaf','./images/sheaf.jpg');

insert into parameter (id, value)
values('TECH/CREATURES/NEXTOBJECTID', 40000);

commit;