BEGIN TRANSACTION;

 drop table if exists Article ;
 drop table if exists Stock ;
 drop table if exists Inventory ;
 drop table if exists Species ;
 drop table if exists Ingredient ;
 drop table if exists Creature ;
 drop table if exists Zone ;
 drop table if exists Phenomenon ;
 drop table if exists Activity ;
 drop table if exists ContainerType ;
 drop table if exists Recipe ;
 drop table if exists LivingCondition ;
 drop table if exists Market ;
 drop table if exists Field ;
 drop table if exists Image ;
 drop table if exists Parameter ;

-- Article
create table Article (
  id                        varchar(32) not null,
  volume                    float not null,
  shelf_time                int not null,
  value_for_obj_fun         float,
  image_id                  varchar(32),
  constraint pk_Article primary key (id)
  
) ;

-- Stock
create table Stock (
  id                        varchar(32) not null,
  capacity                  float not null,
  change_shelf_time int,
  constraint pk_Stock primary key (id)
) ;

-- Inventory
create table Inventory (
  stock_id                 constraint fk_Stock references Stock (id) ,
  article_id                constraint fk_Article references Article (id),
  shelf_time                int not null,
  quant                     float,
  constraint pk_Inventory primary key (stock_id,article_id,shelf_time)
  ) ;

-- Species
create table Species (
  id                        varchar2(32) not null,
  activities_count          int,
  crossover_probability     float,
  mutation_probability      float,
  crossover_type            varchar(32),
  initial_stock_id          varchar(32),
  constraint pk_Species primary key (id)
) ;

-- Ingredient
create table Ingredient (
  recipe_id                 constraint fk_Recipe references Recipe (id) ,
  article_id                constraint fk_Article references Article (id) ,
  article_quant             float,
  article_container         varchar2(32) not null,
  article_role              varchar(32) not null,
  constraint pk_Ingredient primary key (recipe_id,article_id,article_container,article_role)
) ;

-- Creature
create table Creature (
  id                        varchar(32) not null,
  species_id        constraint fk_Species references Species (id) ,
  age                       int,
  backpack_id       constraint fk_Backpack references Stock (id) ,
  position_x                int,
  position_y                int,
  image_id                  varchar(32),
  constraint pk_Creature primary key (id)
) ;

-- Zone
create table Zone (
  id                        varchar(32) not null,
  coordinate_x              int not null,
  coordinate_y              int not null,
  size_x                    int,
  size_y                    int,
  image_id                  varchar(32),
  constraint pk_Zone primary key (id)
) ;

-- Phenomenon
create table Phenomenon (
  id                   varchar(32) not null,
  definition_id          constraint fk_Recipe references Recipe (id) ,
  init_position_y           int not null,
  init_position_x           int not null,
  frequency                 int,
  max_occurrence_at_moment  int,
  range                     int,
  constraint pk_Phenomenon primary key (id)
) ;

-- Activity
create table Activity (
  creature_id            constraint fk_Creature references Creature (id) ,
  lp                        int not null,
  definition_id            constraint fk_Recipe references Recipe (id) ,
  constraint pk_Activity primary key (creature_id,lp)
) ;

-- ContainerType
create table ContainerType (
  id                        varchar(32) not null,
  description               varchar(128),
  constraint pk_ContainerType primary key (id)
) ;

-- Recipe
create table Recipe (
  id                        varchar(32),
  owner_id                  constraint fk_Owner references ContainerType (id) ,
  position_x_influence      int,
  position_y_influence      int,
    constraint pk_Recipe primary key (id)
) ;

-- LivingCondition
create table LivingCondition (
  zone_id                 constraint fk_Zone references Zone (id) ,
  species_id            constraint fk_Species references Species (id) ,
  creatures_limit           int,
  creatures_limit_grid_size int,
  mate_grid_size            int,
  mate_probability float,
  constraint pk_LivingCondition primary key (zone_id,species_id)
) ;

-- Market
create table Market (
  store_id                constraint fk_Store references Stock (id) ,
  position_x                int,
  position_y                int,
  size_x                    int,
  size_y                    int,
  constraint pk_Market primary key (store_id)
) ;

-- Field
create table Field (
  resource_id              constraint fk_Resource references Stock (id) ,
  position_x                int,
  position_y                int,
  constraint pk_Field primary key (resource_id)
) ;

-- Image
create table Image (
  id                        varchar(32) not null,
  path                      varchar(256),
  constraint pk_Image primary key (id)
) ;

-- Parameter
create table Parameter (
  id                        varchar(256) not null,
  value                     varchar(256),
  constraint pk_Parameter primary key (id)
) ;

insert into ContainerType (id, description)
values ("creature", "Source or destination is creature");

insert into ContainerType (id, description)
values ("field", "Source or destination is field");

insert into ContainerType (id, description)
values ("market", "Source or destination is market");

insert into image (id, path) values ('human','./images/human.gif');
insert into image (id, path) values ('dog','./images/dog.gif');
insert into image (id, path) values ('desert','./images/desert.gif');
insert into image (id, path) values ('wood','./images/wood.gif');
insert into image (id, path) values ('water','./images/water.gif');
insert into image (id, path) values ('forest','./images/forest.gif');
insert into image (id, path) values ('soil','./images/soil.gif');
insert into image (id, path) values ('seed_of_grain','./images/seed_of_grain.gif');
insert into image (id, path) values ('grain','./images/grain.gif');
insert into image (id, path) values ('energy','./images/energy.gif');
insert into image (id, path) values ('seed_of_tree','./images/seed_of_tree.gif');
insert into image (id, path) values ('flour','./images/flour.gif');
insert into image (id, path) values ('bread','./images/bread.gif');
insert into image (id, path) values ('coin','./images/coin.gif');
insert into image (id, path) values ('sheaf','./images/sheaf.gif');
insert into image (id, path) values ('tree','./images/tree.gif');
insert into image (id, path) values ('swamp','./images/swamp.jpg');

insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('water',1.0,1000*356, 2,'water');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('soil',2.0,200*356, 1,'soil');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('seed_of_grain',0.001,50*356,1,'seed_of_grain');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('grain',0.01,1*356, 3,'grain');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('energy',0.0000001,30,1,'energy');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('seed_of_tree',0.001,50*356,1,'seed_of_tree');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('wood',3,100*356,5,'wood');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('flour',2,3*356,10,'flour');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('bread',2,14, 20,'bread');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('coin',0.01,500*356,1,'coin');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('sheaf',20,3*356,10,'sheaf');
insert into article (id, volume, shelf_time, value_for_obj_fun, image_id) values ('tree',50,5*356,2,'tree');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_up','creature',0,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_up','energy', 1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right','creature',1,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right','energy', 1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right_up','creature',1,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right_up','energy', 2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left','creature',-1,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left','energy', 1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left_up','creature',-1,1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left_up','energy',2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_down','creature',0,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_down','energy',1,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_right_down','creature',1,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_right_down','energy',2,'creature','resource');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('step_left_down','creature',-1,-1);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('step_left_down','energy',2,'creature','resource');


insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('rainfall','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('rainfall','water',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_grain_appearance','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('seed_of_grain_appearance','seed_of_grain',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_tree_appearance','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) values ('seed_of_tree_appearance','seed_of_tree',1,'field','product');

insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('soil_appearance','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('soil_appearance','soil',1,'field','product');
-- zbieranie wody
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('water_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('water_picking','water',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('water_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('water_picking','water',1,'field','resource');
-- zbieranie ziaren zbóż
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_grain_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_grain_picking','seed_of_grain',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_grain_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_grain_picking','seed_of_grain',1,'field','resource');
-- sianie zboża
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('sow_grain','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','seed_of_grain',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('sow_grain','seed_of_grain',1,'field','product');
-- wzrost zboża
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('grain_growth','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('grain_growth','grain',1,'field','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','seed_of_grain',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','soil',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('grain_growth','water',1,'field','resource');
-- żniwa
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('harvest','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('harvest','sheaf',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('harvest','grain',10,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('harvest','energy',1,'creature','resource');
-- mielenie zboża 
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('flour_milling','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('flour_milling','flour', 1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('flour_milling','sheaf', 1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('flour_milling','energy',1,'creature','resource');
-- wypiek chleba
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('bread_baking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('bread_baking','bread', 1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_baking','flour', 1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_baking','water', 1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_baking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_baking','wood',1,'creature','resource');
-- zjadanie chleba
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('bread_eating','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('bread_eating','energy', 1000,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_eating','bread', 1,'creature','resource');

-- odzyskiwanie energii ???? 
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('energy_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('energy_picking','energy', 1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('energy_picking','energy', 2,'field','resource');

-- picie wody
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('water_drinking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('water_drinking','energy', 50,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('water_drinking','water', 1,'creature','resource');

-- zbieranie ziaren drzew
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('seed_of_tree_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_tree_picking','seed_of_tree',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_tree_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('seed_of_tree_picking','seed_of_tree',1,'field','resource');
-- sadzenie drzew
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('planting_tree','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('planting_tree','seed_of_tree',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('planting_tree','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('planting_tree','water',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('planting_tree','seed_of_tree',1,'field','product');
-- wzrost drzewa
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('tree_growth','field',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('tree_growth','tree',1,'field','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('tree_growth','seed_of_tree',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('tree_growth','soil', 2,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('tree_growth','water', 2,'field','resource');
-- wycinka drzew
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('cutting_tree','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role)
values ('cutting_tree','wood',5,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('cutting_tree','tree',1,'field','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('cutting_tree','energy', 1,'creature','resource');

-- zbieranie drewna
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('wood_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('wood_picking','wood',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('wood_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('wood_picking','wood',1,'field','resource');
-- zbieranie mąki
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('flour_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('flour_picking','flour',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('flour_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('flour_picking','flour',1,'field','resource');

-- zbieranie chleba
insert into recipe (id, owner_id, position_x_influence, position_y_influence) values ('bread_picking','creature',0,0);
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_picking','bread',1,'creature','product');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_picking','energy',1,'creature','resource');
insert into ingredient (recipe_id, article_id, article_quant, article_container, article_role) 
values ('bread_picking','bread',1,'field','resource');

insert into zone (id, coordinate_x, coordinate_y, size_x, size_y, image_id) values ('desert',0,0,12,12,'desert');
insert into zone (id, coordinate_x, coordinate_y, size_x, size_y, image_id) values ('forest',12,0,2,2,'forest');
insert into zone (id, coordinate_x, coordinate_y, size_x, size_y, image_id) values ('swamp',12,8,2,2,'swamp');

insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('rainfall1',  5, 'rainfall', 200, 4, 4, 7);
 insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('soil_appearance1',  16, 'soil_appearance', 200,  4,  4,6); 
 insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('rainfall2',  5, 'rainfall', 100, 8, 8, 5);
insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('seed_of_grain_appearance',  2, 'seed_of_grain_appearance', 20, 5, 5, 5); 
insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('seed_of_tree_appearance',  2, 'seed_of_tree_appearance', 20, 5, 5,5); 
insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('grain_growth',  2, 'grain_growth', 200, 4, 4, 6); 
 insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
 values ('soil_appearance2',  12, 'soil_appearance', 200, 7, 7,6); 
insert into phenomenon (id, frequency, definition_id, max_occurrence_at_moment, init_position_x, init_position_y, range)
values ('tree_growth',  2, 'tree_growth', 100, 4,4,5); 



----
insert into species (id, activities_count, crossover_probability, mutation_probability, crossover_type, initial_stock_id)
 values ('human',16,0.9,0.01,'one_point','human_initial_stock');
insert into species (id, activities_count, crossover_probability, mutation_probability, crossover_type, initial_stock_id) 
values ('dog',16,0.8,0.01,'one_point','dog_initial_stock');

insert into stock (id, capacity, change_shelf_time) values ('human_initial_stock', 1000, 0);
insert into inventory (stock_id, article_id, shelf_time, quant)  
select 'human_initial_stock', id, shelf_time, 1000 from article where id='energy'; 

insert into stock (id, capacity, change_shelf_time) values ('dog_initial_stock', 1000, 0);
insert into inventory (stock_id, article_id, shelf_time, quant)  
select 'dog_initial_stock', id, shelf_time, 1000 from article where id='energy'; 

insert into livingcondition (zone_id, species_id, creatures_limit, creatures_limit_grid_size, mate_grid_size, mate_probability) 
values ('desert','human', 30,10000,10, 0.2);
insert into livingcondition (zone_id, species_id, creatures_limit, creatures_limit_grid_size, mate_grid_size, mate_probability)
values ('desert','dog',30,10000,5, 0.3);

insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human0','humanB0','human',5, 7, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB0', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB0', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human0', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human0', 2,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human0', 3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human0', 4,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human0', 5,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human0', 6,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human0', 7,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human0', 8,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human0', 9,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human0', 10,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human0', 11,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human0', 12,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human0', 13,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human0', 14,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human0', 15,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human0', 16,'seed_of_grain_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human1','humanB1','human',8, 9, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB1', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB1', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human1', 1,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human1', 2,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human1', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human1', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human1', 5,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human1', 6,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human1', 7,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human1', 8,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human1', 9,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human1', 10,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human1', 11,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human1', 12,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human1', 13,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human1', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human1', 15,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human1', 16,'step_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human2','humanB2','human',2, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB2', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB2', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human2', 1,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human2', 2,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human2', 3,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human2', 4,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human2', 5,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human2', 6,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human2', 7,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human2', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human2', 9,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human2', 10,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human2', 11,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human2', 12,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human2', 13,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human2', 14,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human2', 15,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human2', 16,'step_left_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human3','humanB3','human',9, 4, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB3', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB3', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human3', 1,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human3', 2,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 3,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human3', 4,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 5,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human3', 6,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human3', 7,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human3', 8,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 9,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human3', 10,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human3', 11,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human3', 12,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 13,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human3', 14,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 15,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human3', 16,'flour_milling');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human4','humanB4','human',7, 0, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB4', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB4', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human4', 1,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human4', 2,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human4', 3,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human4', 4,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human4', 5,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human4', 6,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human4', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human4', 8,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human4', 9,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human4', 10,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human4', 11,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human4', 12,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human4', 13,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human4', 14,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human4', 15,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human4', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human5','humanB5','human',0, 11, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB5', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB5', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human5', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human5', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human5', 3,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human5', 4,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human5', 5,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human5', 6,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human5', 7,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human5', 8,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human5', 9,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human5', 10,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human5', 11,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human5', 12,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human5', 13,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human5', 14,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human5', 15,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human5', 16,'seed_of_tree_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human6','humanB6','human',6, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB6', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB6', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human6', 1,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human6', 2,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human6', 5,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human6', 6,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 7,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human6', 8,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human6', 9,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 10,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human6', 11,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human6', 12,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 13,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human6', 14,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human6', 15,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human6', 16,'bread_eating');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human7','humanB7','human',10, 10, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB7', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB7', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human7', 1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 3,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human7', 4,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human7', 5,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 6,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human7', 7,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 8,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human7', 9,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human7', 10,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human7', 11,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human7', 12,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 13,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human7', 14,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human7', 15,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human7', 16,'step_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human8','humanB8','human',5, 7, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB8', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB8', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human8', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 2,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human8', 3,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 4,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human8', 5,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 6,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 7,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 8,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human8', 9,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human8', 10,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human8', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human8', 12,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human8', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 14,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human8', 15,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human8', 16,'flour_milling');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human9','humanB9','human',3, 0, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB9', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB9', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human9', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human9', 2,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human9', 3,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human9', 4,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human9', 5,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human9', 6,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human9', 7,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human9', 8,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human9', 9,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human9', 10,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human9', 11,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human9', 12,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human9', 13,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human9', 14,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human9', 15,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human9', 16,'flour_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human10','humanB10','human',11, 7, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB10', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB10', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human10', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human10', 2,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human10', 3,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human10', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human10', 5,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human10', 6,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human10', 7,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human10', 8,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human10', 9,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human10', 10,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human10', 11,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human10', 12,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human10', 13,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human10', 14,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human10', 15,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human10', 16,'step_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human11','humanB11','human',11, 9, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB11', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB11', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human11', 1,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human11', 2,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human11', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human11', 4,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human11', 5,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human11', 6,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human11', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human11', 8,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human11', 9,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human11', 10,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human11', 11,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human11', 12,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human11', 13,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human11', 14,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human11', 15,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human11', 16,'sow_grain');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human12','humanB12','human',7, 9, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB12', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB12', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human12', 1,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human12', 2,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human12', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human12', 4,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human12', 5,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human12', 6,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human12', 7,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human12', 8,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human12', 9,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human12', 10,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human12', 11,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human12', 12,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human12', 13,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human12', 14,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human12', 15,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human12', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human13','humanB13','human',10, 11, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB13', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB13', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human13', 1,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human13', 2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human13', 3,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human13', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human13', 5,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human13', 6,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human13', 7,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human13', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human13', 9,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human13', 10,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human13', 11,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human13', 12,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human13', 13,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human13', 14,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human13', 15,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human13', 16,'bread_eating');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human14','humanB14','human',7, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB14', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB14', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human14', 1,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human14', 2,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human14', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human14', 4,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human14', 5,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human14', 6,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human14', 7,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human14', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human14', 9,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human14', 10,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human14', 11,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human14', 12,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human14', 13,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human14', 14,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human14', 15,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human14', 16,'bread_baking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human15','humanB15','human',7, 10, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB15', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB15', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human15', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human15', 2,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human15', 3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human15', 4,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human15', 5,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human15', 6,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human15', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human15', 8,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human15', 9,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human15', 10,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human15', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human15', 12,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human15', 13,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human15', 14,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human15', 15,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human15', 16,'flour_milling');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human16','humanB16','human',4, 0, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB16', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB16', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human16', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human16', 2,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human16', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human16', 4,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human16', 5,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human16', 6,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human16', 7,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human16', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human16', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human16', 10,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human16', 11,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human16', 12,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human16', 13,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human16', 14,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human16', 15,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human16', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human17','humanB17','human',5, 3, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB17', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB17', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human17', 1,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human17', 2,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human17', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human17', 4,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human17', 5,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human17', 6,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human17', 7,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human17', 8,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human17', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human17', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human17', 11,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human17', 12,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human17', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human17', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human17', 15,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human17', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human18','humanB18','human',3, 9, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB18', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB18', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human18', 1,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human18', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human18', 3,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human18', 4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human18', 5,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 6,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 7,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human18', 8,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 9,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 10,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 11,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 12,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human18', 13,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human18', 14,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human18', 15,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human18', 16,'bread_baking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human19','humanB19','human',2, 11, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB19', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB19', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human19', 1,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human19', 2,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human19', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human19', 4,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human19', 5,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human19', 6,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human19', 7,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human19', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human19', 9,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human19', 10,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human19', 11,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human19', 12,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human19', 13,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human19', 14,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human19', 15,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human19', 16,'step_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human20','humanB20','human',11, 3, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB20', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB20', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human20', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human20', 2,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human20', 3,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human20', 4,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human20', 5,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human20', 6,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human20', 7,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human20', 8,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human20', 9,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human20', 10,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human20', 11,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human20', 12,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human20', 13,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human20', 14,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human20', 15,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human20', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human21','humanB21','human',10, 5, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB21', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB21', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human21', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human21', 2,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human21', 3,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human21', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human21', 5,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 6,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 7,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 8,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human21', 9,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 10,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human21', 11,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human21', 12,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 13,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human21', 14,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human21', 15,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human21', 16,'step_left_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human22','humanB22','human',7, 1, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB22', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB22', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human22', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human22', 2,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human22', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human22', 4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human22', 5,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human22', 6,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human22', 7,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human22', 8,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human22', 9,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human22', 10,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human22', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human22', 12,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human22', 13,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human22', 14,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human22', 15,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human22', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human23','humanB23','human',10, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB23', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB23', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human23', 1,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human23', 2,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human23', 3,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human23', 4,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human23', 5,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human23', 6,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human23', 7,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human23', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human23', 9,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human23', 10,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human23', 11,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human23', 12,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human23', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human23', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human23', 15,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human23', 16,'step_right_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human24','humanB24','human',0, 1, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB24', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB24', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human24', 1,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human24', 2,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human24', 3,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human24', 4,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('human24', 5,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human24', 6,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human24', 7,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human24', 8,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human24', 9,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human24', 10,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human24', 11,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human24', 12,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human24', 13,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human24', 14,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human24', 15,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human24', 16,'seed_of_grain_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human25','humanB25','human',6, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB25', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB25', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human25', 1,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human25', 2,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human25', 3,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human25', 4,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human25', 5,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human25', 6,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human25', 7,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human25', 8,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human25', 9,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human25', 10,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human25', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human25', 12,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('human25', 13,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human25', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human25', 15,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human25', 16,'step_right_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human26','humanB26','human',0, 11, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB26', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB26', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human26', 1,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human26', 2,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human26', 3,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human26', 4,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human26', 5,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human26', 6,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human26', 7,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human26', 8,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human26', 9,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human26', 10,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('human26', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human26', 12,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human26', 13,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human26', 14,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human26', 15,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human26', 16,'wood_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human27','humanB27','human',7, 11, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB27', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB27', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human27', 1,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 2,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human27', 3,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 4,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 5,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('human27', 6,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 7,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human27', 8,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human27', 9,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('human27', 10,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 11,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human27', 12,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human27', 13,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human27', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human27', 15,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human27', 16,'cutting_tree');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human28','humanB28','human',1, 6, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB28', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB28', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human28', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human28', 2,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('human28', 3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human28', 4,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human28', 5,'step_right');
insert into activity (creature_id, lp, definition_id) values ('human28', 6,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human28', 7,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human28', 8,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human28', 9,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human28', 10,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('human28', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('human28', 12,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human28', 13,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human28', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('human28', 15,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human28', 16,'flour_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('human29','humanB29','human',7, 2, 0,'human');
insert into stock (id, capacity, change_shelf_time) values ('humanB29', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'humanB29', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('human29', 1,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human29', 2,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human29', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('human29', 4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human29', 5,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('human29', 6,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('human29', 7,'step_up');
insert into activity (creature_id, lp, definition_id) values ('human29', 8,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('human29', 9,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('human29', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human29', 11,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('human29', 12,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('human29', 13,'step_down');
insert into activity (creature_id, lp, definition_id) values ('human29', 14,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('human29', 15,'step_left');
insert into activity (creature_id, lp, definition_id) values ('human29', 16,'seed_of_grain_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog0','dogB0','dog',11, 10, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB0', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB0', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog0', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 2,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog0', 5,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog0', 6,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog0', 7,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 8,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog0', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog0', 11,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog0', 12,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 13,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog0', 14,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog0', 15,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog0', 16,'step_left_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog1','dogB1','dog',6, 7, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB1', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB1', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog1', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog1', 2,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog1', 3,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog1', 4,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog1', 5,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog1', 6,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog1', 7,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog1', 8,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog1', 9,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog1', 10,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog1', 11,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog1', 12,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog1', 13,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog1', 14,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog1', 15,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog1', 16,'bread_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog2','dogB2','dog',8, 3, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB2', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB2', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog2', 1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog2', 2,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog2', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog2', 4,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog2', 5,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog2', 6,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog2', 7,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog2', 8,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog2', 9,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog2', 10,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog2', 11,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog2', 12,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog2', 13,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog2', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog2', 15,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog2', 16,'step_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog3','dogB3','dog',7, 0, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB3', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB3', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog3', 1,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog3', 2,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog3', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 4,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 5,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog3', 6,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 7,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 8,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog3', 9,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog3', 10,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 11,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 12,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 13,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 14,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog3', 15,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog3', 16,'step_right_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog4','dogB4','dog',5, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB4', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB4', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog4', 1,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog4', 2,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog4', 3,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog4', 4,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog4', 5,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog4', 6,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog4', 7,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog4', 8,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog4', 9,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog4', 10,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog4', 11,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog4', 12,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog4', 13,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog4', 14,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog4', 15,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog4', 16,'step_down');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog5','dogB5','dog',11, 7, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB5', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB5', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog5', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog5', 2,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog5', 3,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 4,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog5', 5,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 6,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog5', 7,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog5', 8,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog5', 9,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog5', 10,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 11,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 12,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 13,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog5', 14,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog5', 15,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog5', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog6','dogB6','dog',1, 3, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB6', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB6', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog6', 1,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog6', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog6', 3,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog6', 4,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog6', 5,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog6', 6,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog6', 7,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog6', 8,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog6', 9,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog6', 10,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog6', 11,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog6', 12,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog6', 13,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog6', 14,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog6', 15,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog6', 16,'seed_of_tree_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog7','dogB7','dog',2, 8, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB7', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB7', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog7', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 2,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 3,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 4,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog7', 5,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog7', 6,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 7,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 8,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog7', 9,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog7', 10,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog7', 11,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog7', 12,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog7', 13,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog7', 14,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog7', 15,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog7', 16,'seed_of_tree_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog8','dogB8','dog',7, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB8', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB8', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog8', 1,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog8', 2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog8', 3,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog8', 4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog8', 5,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog8', 6,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog8', 7,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog8', 8,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog8', 9,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog8', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog8', 11,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog8', 12,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog8', 13,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog8', 14,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog8', 15,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog8', 16,'bread_baking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog9','dogB9','dog',2, 10, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB9', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB9', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog9', 1,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog9', 2,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog9', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog9', 4,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog9', 5,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog9', 6,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 7,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog9', 8,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog9', 9,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog9', 10,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 11,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 12,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 13,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 14,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 15,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog9', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog10','dogB10','dog',6, 3, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB10', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB10', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog10', 1,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog10', 2,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog10', 3,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog10', 4,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog10', 5,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog10', 6,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog10', 7,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog10', 8,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog10', 9,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog10', 10,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog10', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog10', 12,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog10', 13,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog10', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog10', 15,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog10', 16,'bread_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog11','dogB11','dog',10, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB11', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB11', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog11', 1,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog11', 2,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog11', 3,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog11', 4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog11', 5,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog11', 6,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog11', 7,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog11', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog11', 9,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog11', 10,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog11', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog11', 12,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog11', 13,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog11', 14,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog11', 15,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog11', 16,'seed_of_tree_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog12','dogB12','dog',5, 1, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB12', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB12', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog12', 1,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog12', 2,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog12', 3,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog12', 4,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog12', 5,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog12', 6,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog12', 7,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog12', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog12', 9,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog12', 10,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog12', 11,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog12', 12,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog12', 13,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog12', 14,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog12', 15,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog12', 16,'bread_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog13','dogB13','dog',9, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB13', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB13', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog13', 1,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog13', 2,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog13', 3,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog13', 4,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog13', 5,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog13', 6,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog13', 7,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog13', 8,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog13', 9,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog13', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog13', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog13', 12,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog13', 13,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog13', 14,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog13', 15,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog13', 16,'bread_eating');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog14','dogB14','dog',7, 5, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB14', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB14', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog14', 1,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog14', 2,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog14', 3,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog14', 4,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog14', 5,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 6,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog14', 7,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 8,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 9,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 10,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 11,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog14', 12,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog14', 13,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog14', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog14', 15,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog14', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog15','dogB15','dog',7, 3, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB15', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB15', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog15', 1,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog15', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog15', 3,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog15', 4,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog15', 5,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog15', 6,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog15', 7,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog15', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog15', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog15', 10,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog15', 11,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog15', 12,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog15', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog15', 14,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog15', 15,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog15', 16,'flour_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog16','dogB16','dog',7, 7, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB16', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB16', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog16', 1,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog16', 2,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog16', 3,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog16', 4,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog16', 5,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog16', 6,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog16', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog16', 8,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog16', 9,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog16', 10,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog16', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog16', 12,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog16', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog16', 14,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog16', 15,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog16', 16,'cutting_tree');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog17','dogB17','dog',7, 2, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB17', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB17', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog17', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog17', 2,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog17', 3,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog17', 4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog17', 5,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog17', 6,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog17', 7,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog17', 8,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog17', 9,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog17', 10,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog17', 11,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog17', 12,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog17', 13,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog17', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog17', 15,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog17', 16,'step_left');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog18','dogB18','dog',7, 1, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB18', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB18', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog18', 1,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog18', 2,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog18', 3,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog18', 4,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog18', 5,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog18', 6,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog18', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog18', 8,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog18', 9,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog18', 10,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog18', 11,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog18', 12,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog18', 13,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog18', 14,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog18', 15,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog18', 16,'step_right_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog19','dogB19','dog',0, 10, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB19', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB19', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog19', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 3,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog19', 4,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 5,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 6,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog19', 7,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog19', 8,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog19', 10,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog19', 11,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog19', 12,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog19', 13,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog19', 14,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog19', 15,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog19', 16,'wood_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog20','dogB20','dog',0, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB20', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB20', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog20', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog20', 2,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog20', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog20', 4,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog20', 5,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 6,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog20', 7,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 8,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog20', 9,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 10,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog20', 11,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 12,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog20', 13,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 14,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog20', 15,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog20', 16,'energy_picking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog21','dogB21','dog',7, 11, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB21', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB21', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog21', 1,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog21', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog21', 3,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog21', 4,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog21', 5,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog21', 6,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog21', 7,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog21', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog21', 9,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog21', 10,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog21', 11,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog21', 12,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog21', 13,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog21', 14,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog21', 15,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog21', 16,'step_left_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog22','dogB22','dog',10, 11, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB22', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB22', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog22', 1,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 2,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog22', 3,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog22', 4,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog22', 5,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 6,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog22', 7,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog22', 8,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 9,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 10,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog22', 11,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 12,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog22', 13,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog22', 14,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog22', 15,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog22', 16,'planting_tree');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog23','dogB23','dog',9, 0, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB23', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB23', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog23', 1,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog23', 2,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog23', 3,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog23', 5,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog23', 6,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog23', 7,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog23', 8,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog23', 9,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 10,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog23', 11,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 12,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 13,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 14,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog23', 15,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog23', 16,'bread_baking');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog24','dogB24','dog',10, 0, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB24', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB24', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog24', 1,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 2,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog24', 3,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog24', 4,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog24', 5,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 6,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog24', 7,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 8,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 9,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog24', 10,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog24', 11,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 12,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog24', 13,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog24', 14,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 15,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog24', 16,'cutting_tree');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog25','dogB25','dog',2, 1, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB25', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB25', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog25', 1,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog25', 2,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog25', 3,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog25', 4,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog25', 5,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog25', 6,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog25', 7,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog25', 8,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog25', 9,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog25', 10,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog25', 11,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog25', 12,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog25', 13,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog25', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog25', 15,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog25', 16,'step_right_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog26','dogB26','dog',7, 0, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB26', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB26', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog26', 1,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog26', 2,'cutting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog26', 3,'flour_picking');
insert into activity (creature_id, lp, definition_id) values ('dog26', 4,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog26', 5,'sow_grain');
insert into activity (creature_id, lp, definition_id) values ('dog26', 6,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog26', 7,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog26', 8,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog26', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog26', 10,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog26', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog26', 12,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog26', 13,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog26', 14,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog26', 15,'water_picking');
insert into activity (creature_id, lp, definition_id) values ('dog26', 16,'step_right_up');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog27','dogB27','dog',1, 8, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB27', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB27', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog27', 1,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog27', 2,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog27', 3,'step_left_down');
insert into activity (creature_id, lp, definition_id) values ('dog27', 4,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog27', 5,'harvest');
insert into activity (creature_id, lp, definition_id) values ('dog27', 6,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog27', 7,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog27', 8,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog27', 9,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog27', 10,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog27', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog27', 12,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog27', 13,'step_right');
insert into activity (creature_id, lp, definition_id) values ('dog27', 14,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog27', 15,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog27', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog28','dogB28','dog',9, 11, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB28', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB28', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog28', 1,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 2,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 3,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog28', 4,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 5,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog28', 6,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 7,'wood_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 8,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 9,'energy_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 10,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 11,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog28', 12,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 13,'water_drinking');
insert into activity (creature_id, lp, definition_id) values ('dog28', 14,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog28', 15,'step_up');
insert into activity (creature_id, lp, definition_id) values ('dog28', 16,'step_right');
insert into creature (id, backpack_id, species_id, position_x, position_y, age, image_id) values ('dog29','dogB29','dog',11, 6, 0,'dog');
insert into stock (id, capacity, change_shelf_time) values ('dogB29', 100, 1);
insert into inventory (stock_id, article_id, shelf_time, quant)  select 'dogB29', id, shelf_time, 10000 from article where id='energy'; 
insert into activity (creature_id, lp, definition_id) values ('dog29', 1,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog29', 2,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog29', 3,'step_right_down');
insert into activity (creature_id, lp, definition_id) values ('dog29', 4,'bread_baking');
insert into activity (creature_id, lp, definition_id) values ('dog29', 5,'flour_milling');
insert into activity (creature_id, lp, definition_id) values ('dog29', 6,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog29', 7,'bread_eating');
insert into activity (creature_id, lp, definition_id) values ('dog29', 8,'step_right_up');
insert into activity (creature_id, lp, definition_id) values ('dog29', 9,'step_down');
insert into activity (creature_id, lp, definition_id) values ('dog29', 10,'step_left_up');
insert into activity (creature_id, lp, definition_id) values ('dog29', 11,'step_left');
insert into activity (creature_id, lp, definition_id) values ('dog29', 12,'seed_of_grain_picking');
insert into activity (creature_id, lp, definition_id) values ('dog29', 13,'bread_picking');
insert into activity (creature_id, lp, definition_id) values ('dog29', 14,'seed_of_tree_picking');
insert into activity (creature_id, lp, definition_id) values ('dog29', 15,'planting_tree');
insert into activity (creature_id, lp, definition_id) values ('dog29', 16,'bread_eating');
insert into stock (id, capacity, change_shelf_time) values ('F0x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x0', 0, 0);
insert into stock (id, capacity, change_shelf_time) values ('F0x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x2', 0, 2);
insert into stock (id, capacity, change_shelf_time) values ('F0x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x3', 0, 3);
insert into stock (id, capacity, change_shelf_time) values ('F0x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x4', 0, 4);
insert into stock (id, capacity, change_shelf_time) values ('F0x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x5', 0, 5);
insert into stock (id, capacity, change_shelf_time) values ('F0x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x6', 0, 6);
insert into stock (id, capacity, change_shelf_time) values ('F0x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x7', 0, 7);
insert into stock (id, capacity, change_shelf_time) values ('F0x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x8', 0, 8);
insert into stock (id, capacity, change_shelf_time) values ('F0x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x9', 0, 9);
insert into stock (id, capacity, change_shelf_time) values ('F0x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x10', 0, 10);
insert into stock (id, capacity, change_shelf_time) values ('F0x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F0x11', 0, 11);
insert into stock (id, capacity, change_shelf_time) values ('F1x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x0', 1, 0);
insert into stock (id, capacity, change_shelf_time) values ('F1x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x1', 1, 1);
insert into stock (id, capacity, change_shelf_time) values ('F1x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x3', 1, 3);
insert into stock (id, capacity, change_shelf_time) values ('F1x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x5', 1, 5);
insert into stock (id, capacity, change_shelf_time) values ('F1x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x6', 1, 6);
insert into stock (id, capacity, change_shelf_time) values ('F1x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x7', 1, 7);
insert into stock (id, capacity, change_shelf_time) values ('F1x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x8', 1, 8);
insert into stock (id, capacity, change_shelf_time) values ('F1x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x9', 1, 9);
insert into stock (id, capacity, change_shelf_time) values ('F1x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F1x10', 1, 10);
insert into stock (id, capacity, change_shelf_time) values ('F2x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x0', 2, 0);
insert into stock (id, capacity, change_shelf_time) values ('F2x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x1', 2, 1);
insert into stock (id, capacity, change_shelf_time) values ('F2x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x2', 2, 2);
insert into stock (id, capacity, change_shelf_time) values ('F2x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x5', 2, 5);
insert into stock (id, capacity, change_shelf_time) values ('F2x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x6', 2, 6);
insert into stock (id, capacity, change_shelf_time) values ('F2x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x7', 2, 7);
insert into stock (id, capacity, change_shelf_time) values ('F2x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x8', 2, 8);
insert into stock (id, capacity, change_shelf_time) values ('F2x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x10', 2, 10);
insert into stock (id, capacity, change_shelf_time) values ('F2x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F2x11', 2, 11);
insert into stock (id, capacity, change_shelf_time) values ('F3x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x0', 3, 0);
insert into stock (id, capacity, change_shelf_time) values ('F3x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x1', 3, 1);
insert into stock (id, capacity, change_shelf_time) values ('F3x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x3', 3, 3);
insert into stock (id, capacity, change_shelf_time) values ('F3x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x4', 3, 4);
insert into stock (id, capacity, change_shelf_time) values ('F3x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x5', 3, 5);
insert into stock (id, capacity, change_shelf_time) values ('F3x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x6', 3, 6);
insert into stock (id, capacity, change_shelf_time) values ('F3x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x9', 3, 9);
insert into stock (id, capacity, change_shelf_time) values ('F3x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x10', 3, 10);
insert into stock (id, capacity, change_shelf_time) values ('F3x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F3x11', 3, 11);
insert into stock (id, capacity, change_shelf_time) values ('F4x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x0', 4, 0);
insert into stock (id, capacity, change_shelf_time) values ('F4x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x2', 4, 2);
insert into stock (id, capacity, change_shelf_time) values ('F4x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x3', 4, 3);
insert into stock (id, capacity, change_shelf_time) values ('F4x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x4', 4, 4);
insert into stock (id, capacity, change_shelf_time) values ('F4x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x5', 4, 5);
insert into stock (id, capacity, change_shelf_time) values ('F4x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x6', 4, 6);
insert into stock (id, capacity, change_shelf_time) values ('F4x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x7', 4, 7);
insert into stock (id, capacity, change_shelf_time) values ('F4x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x8', 4, 8);
insert into stock (id, capacity, change_shelf_time) values ('F4x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x9', 4, 9);
insert into stock (id, capacity, change_shelf_time) values ('F4x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x10', 4, 10);
insert into stock (id, capacity, change_shelf_time) values ('F4x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F4x11', 4, 11);
insert into stock (id, capacity, change_shelf_time) values ('F5x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x0', 5, 0);
insert into stock (id, capacity, change_shelf_time) values ('F5x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x1', 5, 1);
insert into stock (id, capacity, change_shelf_time) values ('F5x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x2', 5, 2);
insert into stock (id, capacity, change_shelf_time) values ('F5x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x3', 5, 3);
insert into stock (id, capacity, change_shelf_time) values ('F5x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x4', 5, 4);
insert into stock (id, capacity, change_shelf_time) values ('F5x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x5', 5, 5);
insert into stock (id, capacity, change_shelf_time) values ('F5x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x6', 5, 6);
insert into stock (id, capacity, change_shelf_time) values ('F5x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x7', 5, 7);
insert into stock (id, capacity, change_shelf_time) values ('F5x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x9', 5, 9);
insert into stock (id, capacity, change_shelf_time) values ('F5x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x10', 5, 10);
insert into stock (id, capacity, change_shelf_time) values ('F5x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F5x11', 5, 11);
insert into stock (id, capacity, change_shelf_time) values ('F6x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x0', 6, 0);
insert into stock (id, capacity, change_shelf_time) values ('F6x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x1', 6, 1);
insert into stock (id, capacity, change_shelf_time) values ('F6x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x2', 6, 2);
insert into stock (id, capacity, change_shelf_time) values ('F6x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x4', 6, 4);
insert into stock (id, capacity, change_shelf_time) values ('F6x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x5', 6, 5);
insert into stock (id, capacity, change_shelf_time) values ('F6x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x6', 6, 6);
insert into stock (id, capacity, change_shelf_time) values ('F6x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x8', 6, 8);
insert into stock (id, capacity, change_shelf_time) values ('F6x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x9', 6, 9);
insert into stock (id, capacity, change_shelf_time) values ('F6x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x10', 6, 10);
insert into stock (id, capacity, change_shelf_time) values ('F6x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F6x11', 6, 11);
insert into stock (id, capacity, change_shelf_time) values ('F7x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x0', 7, 0);
insert into stock (id, capacity, change_shelf_time) values ('F7x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x1', 7, 1);
insert into stock (id, capacity, change_shelf_time) values ('F7x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x2', 7, 2);
insert into stock (id, capacity, change_shelf_time) values ('F7x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x3', 7, 3);
insert into stock (id, capacity, change_shelf_time) values ('F7x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x4', 7, 4);
insert into stock (id, capacity, change_shelf_time) values ('F7x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x5', 7, 5);
insert into stock (id, capacity, change_shelf_time) values ('F7x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x6', 7, 6);
insert into stock (id, capacity, change_shelf_time) values ('F7x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x7', 7, 7);
insert into stock (id, capacity, change_shelf_time) values ('F7x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x8', 7, 8);
insert into stock (id, capacity, change_shelf_time) values ('F7x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x9', 7, 9);
insert into stock (id, capacity, change_shelf_time) values ('F7x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x10', 7, 10);
insert into stock (id, capacity, change_shelf_time) values ('F7x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F7x11', 7, 11);
insert into stock (id, capacity, change_shelf_time) values ('F8x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x1', 8, 1);
insert into stock (id, capacity, change_shelf_time) values ('F8x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x3', 8, 3);
insert into stock (id, capacity, change_shelf_time) values ('F8x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x4', 8, 4);
insert into stock (id, capacity, change_shelf_time) values ('F8x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x5', 8, 5);
insert into stock (id, capacity, change_shelf_time) values ('F8x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x6', 8, 6);
insert into stock (id, capacity, change_shelf_time) values ('F8x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x7', 8, 7);
insert into stock (id, capacity, change_shelf_time) values ('F8x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x8', 8, 8);
insert into stock (id, capacity, change_shelf_time) values ('F8x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x10', 8, 10);
insert into stock (id, capacity, change_shelf_time) values ('F8x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F8x11', 8, 11);
insert into stock (id, capacity, change_shelf_time) values ('F9x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x0', 9, 0);
insert into stock (id, capacity, change_shelf_time) values ('F9x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x2', 9, 2);
insert into stock (id, capacity, change_shelf_time) values ('F9x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x3', 9, 3);
insert into stock (id, capacity, change_shelf_time) values ('F9x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x5', 9, 5);
insert into stock (id, capacity, change_shelf_time) values ('F9x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x6', 9, 6);
insert into stock (id, capacity, change_shelf_time) values ('F9x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x8', 9, 8);
insert into stock (id, capacity, change_shelf_time) values ('F9x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x9', 9, 9);
insert into stock (id, capacity, change_shelf_time) values ('F9x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x10', 9, 10);
insert into stock (id, capacity, change_shelf_time) values ('F9x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F9x11', 9, 11);
insert into stock (id, capacity, change_shelf_time) values ('F10x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x0', 10, 0);
insert into stock (id, capacity, change_shelf_time) values ('F10x1',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x1', 10, 1);
insert into stock (id, capacity, change_shelf_time) values ('F10x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x2', 10, 2);
insert into stock (id, capacity, change_shelf_time) values ('F10x3',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x3', 10, 3);
insert into stock (id, capacity, change_shelf_time) values ('F10x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x4', 10, 4);
insert into stock (id, capacity, change_shelf_time) values ('F10x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x5', 10, 5);
insert into stock (id, capacity, change_shelf_time) values ('F10x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x6', 10, 6);
insert into stock (id, capacity, change_shelf_time) values ('F10x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x7', 10, 7);
insert into stock (id, capacity, change_shelf_time) values ('F10x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x8', 10, 8);
insert into stock (id, capacity, change_shelf_time) values ('F10x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x10', 10, 10);
insert into stock (id, capacity, change_shelf_time) values ('F10x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F10x11', 10, 11);
insert into stock (id, capacity, change_shelf_time) values ('F11x0',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x0', 11, 0);
insert into stock (id, capacity, change_shelf_time) values ('F11x2',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x2', 11, 2);
insert into stock (id, capacity, change_shelf_time) values ('F11x4',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x4', 11, 4);
insert into stock (id, capacity, change_shelf_time) values ('F11x5',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x5', 11, 5);
insert into stock (id, capacity, change_shelf_time) values ('F11x6',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x6', 11, 6);
insert into stock (id, capacity, change_shelf_time) values ('F11x7',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x7', 11, 7);
insert into stock (id, capacity, change_shelf_time) values ('F11x8',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x8', 11, 8);
insert into stock (id, capacity, change_shelf_time) values ('F11x9',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x9', 11, 9);
insert into stock (id, capacity, change_shelf_time) values ('F11x10',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x10', 11, 10);
insert into stock (id, capacity, change_shelf_time) values ('F11x11',10000, 1);
insert into field (resource_id, position_x, position_y) values ('F11x11', 11, 11);

insert into parameter (id, value)
values('TECH/CREATURES/NEXTOBJECTID', 80);

commit;