#include <assert.h>
#include <QSqlTableModel>
#include <QSqlRecord>
#include <QDebug>
#include <QSqlError>
#include <QSqlQuery>
#include <QString>
//#include <QtGui>

#include "articlemanager.h"
#include "imagemanager.h"


bool ArticleManager::load()
{
    QSqlQueryModel model;
    model.setQuery("SELECT * FROM article");
    for (int i = 0; i < model.rowCount(); ++i) {
        QSqlRecord r = model.record(i);
        QString id = r.value("id").toString();
        double volume = r.value("volume").toFloat();
        int shelfTime = r.value("shelf_time").toFloat();
        double valForObjFun = r.value("value_for_obj_fun").toFloat();
        QString imageId = r.value("image_id").toString();
        Article article (id, volume, shelfTime, valForObjFun, imageId);
        merge(article);
        qDebug() << "article " << article.getId() << " loaded";
    }
    return true;
}


bool ArticleManager::save(const Article &article) {
    QMap<QString, QVariant> values;
    values.insert ("id", article.getId());
    values.insert ("volume", article.volume());
    values.insert ("shelf_time", article.getShelfTime());
    values.insert ("value_for_obj_fun", article.valueForObjectiveFunction());
    values.insert ("image_id", article.getImageId());
    return SingletonManagerTemplate::save (values, article.getId());

}

const QImage *ArticleManager::getImage(QString articleId)

{
    const QImage *qimage = NULL;
    const Article *article = find(articleId);
    if (article) {
        const Image *image = ImageManager::getManager()->find (article->getImageId());
        if (image) {
            qimage = image->getImagePtr();
        }
    }
    return qimage;
}
