#ifndef CREATUREMANAGER_H
#define CREATUREMANAGER_H
#include <QString>
#include "managertemplate.h"
#include "model/creature.h"
#include "model/field.h"
#include "speciesmanager.h"
#include "util/area.h"
#include "emitters/messenger.h"

class CreatureManager : public SingletonManagerTemplate<Creature, CreatureManager, QString>
{
public:

    // Wykonaj wszystkie czynności, które osobnik ma zdefiniowane
    // Aktualizuj zapasy w zadanych kontenerach
    void executeActivities(Creature &creature);

    // Wykonaj wszystkie czynności dostępne dla osobnika
    // i niech upływ czasu wpłynie na zawartość plecaka osobnika
    void dayActivity(QString creatureId);

    // Jeżeli mama i tata są tego samego gatunku, to zastosuj krzyżowanie (wg. prawdopodobieństwa)
    // oraz ewentualnie mutuj dziecię (również zależy od prawdopodobieństwa)
    void mating(const Creature &mom, const Creature &dad, Creature &child);

    // Wyszukaj wszystkie osobniki danego gatunku, które znajdują się w obszarze
    const IdsOfObjects creaturesInArea(const Area &area,
                                        const Species &species) const;

    // Reprodukcja osobników gatunku species w obszarze area.
    // TODO: Warunki reprodukcji powinny zależeć od gatunku.
    // Aktualnie dla wybranych dwóch osobników tworzymy nowego, powinno to być bardziej elastyczne
    void reproduction (const Area &area,
                       const Species &species);

    // Wylicz wartość funkcji celu
    // TODO : Uzależnić od wieku osobnika
    double objectiveValue (const Creature &creature) const;

    // W wyniku działania ciśnienia ewolucyjnego (selekcja naturalna)
    // liczba osobników w danym obszarze może się zmniejszyć.
    // TODO: Ciśnienie powinno zależeć od gatunku i własności obszaru

    // Aktulnie wyrzucamy z obszaru osobniki jeżeli ich liczba przekracza creatureLimit
    // - najsłabsze osobniki (funkcja celu),
    // - które się na nim nie mieszczą (liczba osobników na obszarze jest większa niż 10% pola powierzchni)
    void evolutionaryPressure (const Area &area,
                               const Species &species,
                               int creatureLimit);
    // Wczytaj z domyślej bazy dancyh informację o osobnikach. Aktualnie znajdujące się obiekty
    // w managerze nie są czyszczone.
    bool load();
    bool save(const Creature &creature);
    QString getTableName () const { return "creature"; }
    QString getIdFilter (QString id) const { return QString ("id = '%1'").arg(id); }

    // Ustaw wskazanie do obiektu za pomocą którego będziemy informowali o rożnych zdarzeniach w świecie
    void setMessenger (Messenger *messenger);

    // Inicjuj pola
    virtual void init();

    // Licz osobniki, które dodajesz do cache
    virtual void merge(const Creature &object);
    void remove(QString id);

    // Ustaw numer/id następnego tworzonego osognika
    // - wykorzystywane jako parametr aplikacji
    // aby zapamiętać i ustawiać id osobników
    void setNextObjectId (unsigned long next);
    unsigned long getNextObjectId();
protected:

    virtual bool removeDependent (QString creatureId);

private:
    Messenger *messenger;
    unsigned long nextObjectId;
};

#endif // CREATUREMANAGER_H
