#include <assert.h>
#include <assert.h>
#include <QSqlTableModel>
#include <QSqlRecord>
#include <QDebug>
#include <QSqlError>
#include <QSqlQuery>
#include "fieldmanager.h"
#include "stockmanager.h"

bool FieldManager::load()
{
    StockManager *stockManager = StockManager::getManager();
    QSqlQueryModel model;

    model.setQuery("SELECT * FROM field");
    for (int i = 0; i < model.rowCount(); ++i) {
        QSqlRecord r = model.record(i);
        QString resourceId = r.value("resource_id").toString();
        int x = r.value("position_x").toInt();
        int y = r.value("position_y").toInt();
        const Stock *resource = stockManager->find(resourceId);
        if (resource == NULL)
            qFatal("%s", QString ("resource %1 not found while loading field ").arg(resourceId).toStdString().c_str() );

        Field field (resourceId, x, y);

        merge(field);
        qDebug() << "field " << field.getId() << "(" << x << ", " << y << ")" << " loaded ";
    }
    return true;
}



bool FieldManager::save(const Field &field)
{
    QMap<QString, QVariant> values;
    values.insert ("resource_id", field.getId());
    values.insert ("position_x", field.getCoordinates().x());
    values.insert ("position_y", field.getCoordinates().y());
    return SingletonManagerTemplate::save (values, field.getId());
}

void FieldManager::remove(QString id)
{
    SingletonManagerTemplate::remove(id);
    StockManager::getManager()->remove(find(id)->getResourcesId());
}



struct FieldPositionEqual {
    FieldPositionEqual (int posX, int posY): x(posX), y(posY) {
    }

    bool operator()( const std::pair<QString, const Field &> &rhs) {
        return x == rhs.second.getCoordinates().first
                && y == rhs.second.getCoordinates().second ;
    }
private:
    int x, y;
};

const Field *FieldManager::objectAtPosition(int x, int y) const
{
    Cache::const_iterator field = std::find_if(cache.begin(), cache.end(), FieldPositionEqual(x, y) );
    if (field != cache.end()) {
        return &(field->second);
    }
    return NULL;
}
