#ifndef MANAGERTEMPLATE_H
#define MANAGERTEMPLATE_H
#include <map>
#include <vector>
#include <algorithm>
#include <QMap>
#include <QSqlTableModel>
#include <QSqlRecord>
#include <QSqlError>
#include <QDebug>
template <class Idable, class Singleton, class IdClass>
class SingletonManagerTemplate
{
public:
    class IdsOfObjects : public std::vector<IdClass> {};
    class Cache : public std::map<IdClass, Idable> {};

    static Singleton *getManager() {
        static Singleton *instance = NULL;
        if (instance == NULL) {
            instance = new Singleton();
            instance->init();
        }
        return instance;
    }

    // Poszukaj danych o obiekcie w cache
    const Idable *find(IdClass id) const {
        const Idable *object = NULL;
        typename std::map<IdClass, Idable>::const_iterator i = cache.find(id);
        if ( i != cache.end() )
            object = &(*i).second;
        return object;

    }

    // Załaduj do cache
    virtual void merge(const Idable& object) {
        typename std::map<IdClass, Idable>::iterator i = cache.find(object.getId());
        if ( i != cache.end() )
            (*i).second = object ;
        else {
            std::pair<IdClass, Idable> objectPair (object.getId(), object);
            cache.insert(objectPair);
            // Jeżeli był usunięty, to należy go przywrócić
            typename IdsOfObjects::iterator j = std::find(removed.begin(), removed.end(), object.getId() );
            if (j != removed.end()) {
                removed.erase(j);
            }
        }
    }

   // Wyczyść cache
    virtual void clear() {
        cache.clear();
    }

    const Cache &getCache() const {
        return cache;
    }

    // Usuń z cache
    virtual void remove(IdClass id) {
        cache.erase(id);
        removed.push_back(id);
    }

    virtual bool load() = 0;

    virtual bool saveAll()
    {
        typename Cache::const_iterator i = cache.begin();
        typename Cache::const_iterator e = cache.end();
        bool saved = true;
        while (i != e && saved) {
            saved = save(i->second);
            i++;
        }
        return saved;
    }

    virtual bool save(IdClass objectId)
    {
        const Idable *idable = find(objectId);
        if (idable) {
            qDebug() << "saving " << objectId;
            return save (*idable);
        }
        return false;
    }

    virtual bool save(const Idable &idable) = 0;

    bool applyRemove () {
        typename IdsOfObjects::iterator j = removed.begin();
        typename IdsOfObjects::iterator f = removed.end();
        bool applied = true;
        while (j != f && applied) {
            applied = removeRows (getTableName(), getIdFilter(*j))
                    && removeDependent (*j);
            j++;
        }
        removed.clear();
        return applied;
    }

    virtual void init() {
    }

protected:



    SingletonManagerTemplate() {
        init ();
    }

    ~SingletonManagerTemplate() {
        cache.clear();
        removed.clear();
    }

    Cache cache;
    IdsOfObjects removed;

    bool save (const QMap<QString, QVariant> &fields, IdClass id) {

        return save(getTableName (), getIdFilter (id), fields);
    }


    bool save (QString tableName, QString filter, const QMap<QString, QVariant> &fields) {
        QSqlTableModel model;
        model.setTable(tableName);
        model.setFilter(filter);
        bool saved;
        if ( (saved = model.select()) ) {
            QSqlRecord record = model.record();
            int rowCount = model.rowCount();
            if (rowCount == 0) {
                // Insertujemu
                model.insertRow(0);
            }
            QMapIterator<QString, QVariant> i(fields);
            while(i.hasNext()) {
                i.next();
                model.setData(model.index(0, record.indexOf(i.key())), i.value());
            }
        } else {
            qDebug() << "SQLError 1: " <<model.lastError().text() << model.lastError().databaseText();
        }
        saved = model.submitAll();
        if (!saved) {
            qDebug() << "SQLError 2: " <<model.lastError().text() << model.lastError().databaseText();
        }
        return saved;
    }

    bool removeRows (QString tableName, QString filter) {
        bool rowsRemoved = true;
        QSqlTableModel model;
        model.setTable(tableName);
        model.setFilter(filter);
        if ( (rowsRemoved = model.select()) ) {
            int c = model.rowCount();
            if (c > 0) {
                rowsRemoved = model.removeRows(0, c)
                        && model.submitAll();
            }
        }
        if (!rowsRemoved) {
            qDebug() << " removing rows : " << tableName << " - " << filter << ", err:"
                     << model.lastError().text()
                     << model.lastError().databaseText()
                     << model.database().lastError().text();
        }
        return rowsRemoved;
    }

    virtual QString getTableName () const = 0;
    virtual QString getIdFilter (IdClass id) const = 0;

    virtual bool removeDependent (IdClass) {
        return true;
    }
};




#endif // MANAGERTEMPLATE_H
