#include <assert.h>
#include <assert.h>
#include <QSqlTableModel>
#include <QSqlRecord>
#include <QDebug>
#include <QSqlError>
#include <QSqlQuery>
#include "marketmanager.h"
#include "stockmanager.h"


bool MarketManager::load()
{
    StockManager *stockManager = StockManager::getManager();
    QSqlQueryModel model;
    model.setQuery("SELECT * FROM market");
    for (int i = 0; i < model.rowCount(); ++i) {
        QSqlRecord r = model.record(i);
        QString id = r.value("id").toString();

        QString storeId = r.value("store_id").toString();

        int x = r.value("position_x").toInt();
        int y = r.value("position_y").toInt();

        int sizeX = r.value("size_x").toInt();
        int sizeY = r.value("size_y").toInt();
        const Stock *store = stockManager->find(storeId);

        if (store == NULL)
            qFatal("%s", QString ("resource %1 not found while loading market").arg(storeId).toStdString().c_str() );

        Market market (storeId, x, y, sizeX, sizeY);

        merge(market);
        qDebug() << "market " << market.getId();
    }
    return true;
}

bool MarketManager::save(const Market &market)
{
    QMap<QString, QVariant> values;
    values.insert ("store_id", market.getId());
    values.insert ("position_x", market.getArea().x());
    values.insert ("position_y", market.getArea().x());
    values.insert ("size_x", market.getArea().width());
    values.insert ("size_y", market.getArea().height());
    return SingletonManagerTemplate::save (values, market.getId());
}


struct MarketPositionEqual {
    MarketPositionEqual (int posX, int posY): x(posX), y(posY) {
    }

    bool operator()( const std::pair<QString, const Market &> &rhs) {
        return rhs.second.getArea().contains(Coordinates(x, y));
    }
private:
    int x, y;
};

const Market *MarketManager::objectAtPosition(int x, int y) const
{
    Cache::const_iterator market = std::find_if(cache.begin(), cache.end(), MarketPositionEqual(x, y) );
    if (market != cache.end()) {
        return &(market->second);
    }
    return NULL;
}


