#include "naturalphenomena.h"
#include "fieldmanager.h"
#include "marketmanager.h"
#include "recipeexecutor.h"
#include "stockmanager.h"


void NaturalPhenomena::passageOfTime(int day){
    FieldManager *fieldManager = FieldManager::getManager();
    MarketManager *marketManager = MarketManager::getManager();
    RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
    Cache::iterator nPhenomenonIter = cache.begin();
    Cache::iterator nPhenomenonEnd = cache.end();

    while (nPhenomenonIter != nPhenomenonEnd) {
        Phenomenon *phenomenon = &nPhenomenonIter->second;
        if (day % phenomenon->frequency == 0) {
            // Określamy współrzędną od jakiej zaczynamy działanie zjawiska w obszarze
            int x = phenomenon->initPositionX;
            int y = phenomenon->initPositionY;
            int occurrence = 0;
            int radius = 0;
            int maxOccur = phenomenon->maxOccurrenceAtMoment;
            int phenomenonX, phenomenonY;
            //const Zone::Phenomenon *phenomenon = &(*nPhenomenonIter);
            while (occurrence < maxOccur) {
                int i;
                // Górna linia - z lewej na prawą
                phenomenonY = radius + y;
                for ( i = -radius; i <= radius && occurrence < maxOccur; i++) {
                    phenomenonX = i + x;
                    occurrence++;
                    // Zjawisko dla znalezionego pola i marketu w tym miejscu
                    applyPhenomenon (fieldManager->objectAtPosition(phenomenonX, phenomenonY),
                                     marketManager->objectAtPosition(phenomenonX, phenomenonY),
                                     recipeExecutor->find(phenomenon->definitionId));
                }

                radius++;
                if (radius >= phenomenon->range) {
                    radius = 0;
                }
                // Prawy bok w dół
                phenomenonX = radius + x;
                for ( i = radius - 1; i > -radius && occurrence < maxOccur; i--) {
                    phenomenonY = i + y;
                    occurrence++;
                    // Zjawisko dla znalezionego pola i marketu w tym miejscu
                    applyPhenomenon (fieldManager->objectAtPosition(phenomenonX, phenomenonY),
                                     marketManager->objectAtPosition(phenomenonX, phenomenonY),
                                     recipeExecutor->find(phenomenon->definitionId));
                }

                // Dolna linia (z prawej do lewej)
                phenomenonY = -radius + y;
                for ( i = radius; i > -radius && occurrence < maxOccur; i--) {
                    phenomenonX = i + x;
                    occurrence++;
                    // Zjawisko dla znalezionego pola i marketu w tym miejscu
                    applyPhenomenon (fieldManager->objectAtPosition(phenomenonX, phenomenonY),
                                     marketManager->objectAtPosition(phenomenonX, phenomenonY),
                                     recipeExecutor->find(phenomenon->definitionId));
                }

                // Lewy bok w górę
                phenomenonX = x - radius;
                for ( i = -radius; i < radius && occurrence < maxOccur; i++) {
                    phenomenonY = i + y;
                    occurrence++;
                    // Zjawisko dla znalezionego pola i marketu w tym miejscu
                    applyPhenomenon (fieldManager->objectAtPosition(phenomenonX, phenomenonY),
                                     marketManager->objectAtPosition(phenomenonX, phenomenonY),
                                     recipeExecutor->find(phenomenon->definitionId));
                }


            }
        }

        nPhenomenonIter++;
    }
}

bool NaturalPhenomena::load()
{
    //SpeciesManager *speciesManager = SpeciesManager::getManager();
    RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
    QSqlQueryModel model;
    model.setQuery("SELECT * FROM phenomenon");
    for (int i = 0; i < model.rowCount(); ++i) {
        QSqlRecord v = model.record(i);
        QString id = v.value("id").toString();
        QString definitionId = v.value("definition_id").toString();
        int frequency = v.value("frequency").toInt();
        int maxOccurrence = v.value("max_occurrence_at_moment").toInt();
        int phenomenonRange = v.value("range").toInt();
        int initPositionX = v.value("init_position_x").toInt();
        int initPositionY = v.value("init_position_y").toInt();

        const Recipe *recipe = recipeExecutor->find(definitionId);
        if (recipe == NULL)
            qFatal("%s", QString ("recipe %1 not found while loading zone %2").arg(definitionId).arg(id).toStdString().c_str() );

        Phenomenon phenomenon (id, frequency, *recipe, initPositionX, initPositionY, maxOccurrence, phenomenonRange);
        merge(phenomenon);
        qDebug() << " phenomenon " << id <<" with def" << definitionId  << "loaded";
    }
    return true;
}

bool NaturalPhenomena::save(const Phenomenon &phenomenon)
{
    QMap<QString, QVariant> values;
    values.insert ("id", phenomenon.getId());
    values.insert ("definition_id", phenomenon.definitionId);
    values.insert ("init_position_x", phenomenon.initPositionX);
    values.insert ("init_position_y", phenomenon.initPositionY);
    values.insert ("frequency", phenomenon.frequency);
    values.insert ("max_occurrence_at_moment", phenomenon.maxOccurrenceAtMoment);
    values.insert ("range", phenomenon.range);
    bool saved = SingletonManagerTemplate::save (values, phenomenon.getId());
    return saved;
}


void NaturalPhenomena::applyPhenomenon(const Field *field, const Market *market, const Recipe *definition)
{
    StockManager *stockManager = StockManager::getManager();
    RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
    Stock::Set stocksForPhenomenon;
    if (field != NULL)
        stockManager->appendTo (stocksForPhenomenon, Container::FIELD, field->getResourcesId());
    if (market != NULL)
        stockManager->appendTo (stocksForPhenomenon, Container::MARKET, market->getStockId());
    recipeExecutor->execute(*definition, stocksForPhenomenon);
}
