#ifndef RECIPEEXECUTOR_H
#define RECIPEEXECUTOR_H
 #include <QMutex>

#include "model/recipe.h"
#include "model/stock.h"
#include "model/creature.h"
#include "managertemplate.h"
#include "emitters/messenger.h"

class RecipeExecutor : public SingletonManagerTemplate<Recipe, RecipeExecutor, QString>
{
public:

    // Wykonaj recepturę na podstawie definicji oraz zadanych kontenerów
    bool execute (const Recipe &recipe,
                  Stock::Set &stocks);

    // Wykonaj recepturę na podstawie definicji oraz zadanych kontenerów
    // i osobnika, którego pozycja może w wyniku działania receptury ulec zmianie.
    bool execute (const Recipe &recipe,
                  Stock::Set &stocks,
                  Creature &movable);

    // Wylosuj recepturę przeznaczoną dla ownera.
    // Jeżeli brak receptur, które wykonywać może owner zwróć NULL.
    const Recipe * randomRecipe(Container::Type owner) const;

    // Wyszukaj wszystkie receptur, które mogą być wykonywane na rzecz obiektu o typie owner.
    const IdsOfObjects recipesForOwner(Container::Type owner) const;

    // Wczytaj z domyślej bazy dancyh informację o recepturach. Aktualnie znajdujące się obiekty
    // w managerze nie są czyszczone.
    bool load();
    bool save(const Recipe &recipe);

    QString getTableName () const { return "recipe"; }
    QString getIdFilter (QString id) const { return QString ("id = '%1'").arg(id); }

    void init();
    // Ustaw wskazanie do obiektu za pomocą którego będziemy informowali o rożnych zdarzeniach w świecie
    void setMessenger (Messenger *worldMessenger);

private:

    class StockLock {
    public:
        Stock *stock;
        QMutex *mutex;
    };

    bool necessaryStocksLocked (const Recipe &recipe,
                                Stock::Set &stocks,
                                std::vector<StockLock> &necessaryStocks);

    // Sprawdź czy w zasobach znajdują się wystarczające ilośći dla receptury
    bool haveAvailableQuants (const Recipe &recipe,
                              const Stock::Set &stocks);

    bool containersCapacious(const Recipe &recipe,
                             const Stock::Set &stocks);

    Messenger *messenger;

};

#endif // RECIPEEXECUTOR_H
