#include <assert.h>
#include <QSqlTableModel>
#include <QSqlRecord>
#include <QDebug>
#include <QSqlError>
#include <QSqlQuery>
#include "speciesmanager.h"


bool SpeciesManager::load()
{
    QSqlQueryModel model;
    model.setQuery("SELECT * FROM species");
    for (int i = 0; i < model.rowCount(); ++i) {
        QSqlRecord r = model.record(i);
        QString id = r.value("id").toString();
        int activitieCount = r.value("activities_count").toInt();
        double crossoverProbability = r.value("crossover_probability").toFloat();
        double mutationProbability = r.value("mutation_probability").toFloat();
        QString crossoverType = r.value("crossover_type").toString();
        QString initialStockId = r.value("initial_stock_id").toString();

        Species species (id, activitieCount, initialStockId);
        species.setCrossoverProbability(crossoverProbability);
        species.setMutationProbability(mutationProbability);
        merge(species);
        qDebug() << "species" << species.getId() << " loaded";
    }
    return true;
}

bool SpeciesManager::save(const Species &species)
{
    QMap<QString, QVariant> values;
    values.insert ("id", species.getId());
    values.insert ("activities_count", species.getActivitiesCount());
    values.insert ("crossover_probability", species.getCrossoverProbability());
    values.insert ("mutation_probability", species.getMutationProbability());
    // TODO !! values.insert ("crossover_type", species.getCrossoverProbability);
    values.insert ("initial_stock_id", species.getInitialStockId());
    return SingletonManagerTemplate::save (values, species.getId());
}

