#include "creature.h"
#include "assert.h"

Creature::Creature(QString id, QString creatureImageId)
    : Idable<QString> (id), coordinates(0, 0), age(0), imageId(creatureImageId)
{
    species = QString::null;
}

Creature::Creature(QString id,
                   const Coordinates &bornCoordiantes,
                   const Species &species, const Stock &stock, int age, QString creatureImageId)
    :Idable<QString> (id), coordinates(bornCoordiantes), imageId(creatureImageId)
{
    setSpecies(species);
    backpackId = stock.getId();
    this->age = age;
}

void Creature::move(int deltaX, int deltaY, const Area &world)
{
    coordinates.first += deltaX;
    coordinates.second += deltaY;

    // Jeżeli wykroczyliśmy poza obszar świata, to naprawmy to
    int x = coordinates.first;
    int y = coordinates.second;
    while (x < world.x()) {
        int diff = world.x() - x;
        x = world.width() - diff;
    }
    int endWorldX = world.x() + world.width();
    while (x >= endWorldX) {
        int diff = x - endWorldX;
        x = world.x() + diff;
    }
    while (y < world.y()) {
        int diff = world.y() - y;
        y = world.height() - diff;
    }
    int endWorldY = world.y() +  world.height();
    while (y >= endWorldY) {
        int diff = y - endWorldY;
        y = world.y() + diff;
    }
    coordinates.first = x;
    coordinates.second = y;
}

const QString &Creature::getBackpackId() const
{
    return backpackId;
}

void Creature::setBackpackId(QString creatureBackpackId)
{
    backpackId = creatureBackpackId;
}

const Coordinates &Creature::getCoordinates() const
{
    return coordinates;
}

void Creature::setCoordinates(const Coordinates &newCoordinates)
{
    coordinates = newCoordinates;
}

const Creature::Activities &Creature::getActivities() const
{
    return activities;
}

void Creature::addActivity(const Recipe &activity)
{
    activities.push_back(activity.getId());
}

void Creature::clearActivities()
{
    activities.clear();
}

void Creature::setSpecies(const Species &species)
{
    this->species = species.getId();
}

const QString Creature::getSpeciesId() const
{
    return species;
}

void Creature::increaseAge()
{
    age++;
}

int Creature::getAge() const
{
    return age;
}

const QString Creature::getImageId() const
{
    return imageId;
}

