#ifndef STOCK_H
#define STOCK_H

#include <math.h>
#include <map>
#include <list>
#include "article.h"
#include "container.h"
#include "idable.h"
#include "QString"
class Stock  : public Idable<QString>
{
public:
    class Set : public std::map<Container::Type, Stock *> {};

    class Batch {
    public:
        double quant;
        int shelfTime; // Jeżeli będzie 0 to towar "znika"
        double volume;
        bool operator == (const Batch &second) {
            return shelfTime == second.shelfTime;
        }
        static bool expireOrNothing(const Batch &batch) {
            return batch.shelfTime <= 0 || batch.quant <= 0.;
        }
        bool operator()(const Batch &lhs, const Batch &rhs) {
            return lhs.shelfTime < rhs.shelfTime;
        }
    };
    class ArticleQuants : public std::list<Batch> {};
    class Articles : public std::map<QString, ArticleQuants> {};
    const Articles &getArticles() const;

    Stock(QString stockId, double startCapacity  = 0.0, bool changeOfShelfTime = true);
    Stock(const Stock &stock);
    ~Stock();

    // Dodaj do zasobów ilość zadanego artykułu.
    // Jeżeli nie mieści się zgłoś błąd.

    void push(const Article &article);
    void push(const Article &article, double quant);
    void push(const Article &article, double quant, unsigned shelfTime);

    // Pobierz z zasobów zadaną ilość artykułu (zmniejsz zasób).
    // Jeżeli brak zasobów zgłoś błąd.
    void pop(const Article &article, double quant);

    // Zdejmij ze stosu podany artykuł w zadanej ilości i przydatności
    // Jeżeli shelfTime <= 0, to będziemy zdejmować fefo.
    void pop(const Article &article, double quant, unsigned shelfTime);

    // Pobierz sumaryczną ilość artukułu
    // (nie patrząc na czas przydatności jeżeli shelfTime <= 0)
    double summaryQuant(QString articleId, int shelfTime = -1) const;

    // Jaka jest dostępna pojemność konterera
    double availableCapacity () const;
    // Ile zajmują towary
    double volumeUsed() const;
    // Liczba różnych "partii" towaru
    int batchesCount(QString articleId);
    // Ustaw pojemność zasobu. Jeżeli aktualnie przekraczamy zadaną pojemność zgłoś błąd.
    void setCapacity (double newCapacity);
    double getCapacity() const;
    // Czy coś jest na składzie?
    bool isEmpty () const;

    // Zaznacz upływ czasu. Artykuły, kóre przekroczyły termin ważności znikają ze stosu
    // Informację o tym, czy zbiór zasobów się zmienił zapisz w stockChanged (jeżeli nie puste)
    void dayPassed(bool *stockChanged = NULL);

    // Czy artykuły w zasobie podglegają wpływowi czasu?
    // Wykorzystywane dla wzorca zasobu dla rodzących się osobników.
    void setChangeOfShelfTime(bool change);
    bool getChangeShelfTime() const;
private:

    // Pojemność
    double capacity;
    // Bieżące objętość artykułów w pojemniku
    double articlesVolume;
    Articles articles;
    bool changeShelfTime;

    // Zmień ilość
    void change (const Article &article, double quant, int shelfTime);
    // Posprzątaj mijesce po artykule wskazywanym przez articleIter
    // Usuń zerowe pozycje
    void cleanUp(Stock::Articles::iterator &articleIter);
};

#endif // STOCK_H
