#include <QStringListModel>
#include <QDebug>
#include <QGridLayout>
#include <QtGui>
#include "activitiesinfoview.h"
#include "controller/recipeexecutor.h"
#include "creatureview.h"
#include "fieldview.h"
#include "controller/imagemanager.h"
#include "controller/creaturemanager.h"
#include "controller/zonemanager.h"


ActivitiesInfoView::ActivitiesInfoView(QWidget *parent) :
    QWidget(parent)
{
    label = new QLabel(this);
    QGridLayout *gridLayout = new QGridLayout;
    tree = new QTreeWidget(this);
    QStringList labels;
    labels << "activity" << "product <- resources" << "position_effect" ;
    tree->setHeaderLabels ( labels);

    gridLayout->addWidget(label);
    gridLayout->addWidget(tree);
    setLayout(gridLayout);
}

void ActivitiesInfoView::displayActivitiesInfo(QString creatureId)
{
    tree->clear();
    label->setText("");
    RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
    const Creature *creature = CreatureManager::getManager()->find(creatureId);
    if (creature) {
        label->setText(creature->getId());
        Creature::Activities::const_iterator activitiesIter = creature->getActivities().begin();
        Creature::Activities::const_iterator activitiesEnd = creature->getActivities().end();

        qDebug() << "Creature " << creature->getId() << " activities";
        QList<QTreeWidgetItem *> items;

        while (activitiesIter != activitiesEnd) {


            QTreeWidgetItem *activityItem = new QTreeWidgetItem(tree);
            activityItem->setText(0, *activitiesIter);

            const Recipe *recipe = recipeExecutor->find(*activitiesIter);
            QString productAndResources;
            Recipe::Products::const_iterator pIter =recipe->getProducts().begin();
            Recipe::Products::const_iterator pIterEnd =recipe->getProducts().end();
            while (pIter != pIterEnd) {
                productAndResources.append(pIter->articleId).append(" ");
                pIter ++;
            }
            productAndResources.append(" <= ");
            Recipe::Resources::const_iterator rIter =recipe->getResources().begin();
            Recipe::Resources::const_iterator rIterEnd =recipe->getResources().end();
            while (rIter != rIterEnd) {
                productAndResources.append(rIter->articleId).append(" ");
                rIter ++;
            }

            activityItem->setText(1, productAndResources);

            if (recipe->getPositionEffect().isEffective()) {
                QString positionEffect ("%1 x %2");
                activityItem->setText(2, positionEffect.arg(recipe->getPositionEffect().deltaX).arg(recipe->getPositionEffect().deltaY));

            }
            items.append(activityItem);
            tree->insertTopLevelItems(0, items);
            activitiesIter++;
        }
    }
}


ActivitiesView::ActivitiesView(QString creatureId, const QColor &color, QGraphicsObject *parent)
    : VisualElement(creatureId, color, 10, parent)
{
    fontSize =  FieldView::FIELD_SIZE / 8;
}


QRectF ActivitiesView::boundingRect() const
{
    return path.boundingRect();
}

QPainterPath ActivitiesView::shape() const
{
    return path;
}

void ActivitiesView::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
{
    Q_UNUSED(widget);
    Q_UNUSED(option);

    if (CreatureView::paintPlannedMovesSelectedCreature
            && getElementId() != QString::null) {
        QPen pen;
        pen.setWidth(1);
        pen.setStyle(Qt::SolidLine);
        painter->save();
        painter->setPen(pen);
        QFont font("Times", fontSize);
        font.setStyleStrategy(QFont::ForceOutline);
        painter->setFont(font);
        const Creature *creature = CreatureManager::getManager()->find(getElementId());
        RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
        Creature::Activities::const_iterator activitiesIter = creature->getActivities().begin();
        Creature::Activities::const_iterator activitiesEnd = creature->getActivities().end();

        QPoint stop;
        int x = 0;
        int y = 0;


        int startX = FieldView::FIELD_SIZE / 2;
        int startY = FieldView::FIELD_SIZE / 2;
        QPoint start (startX, startY);
        int shiftText = 0;
        int counter  = 1;
        QPainterPath empty;
        path = empty;
        while (activitiesIter != activitiesEnd) {
            const Recipe *recipe = recipeExecutor->find(*activitiesIter);
            Recipe::PositionEffect pEffect = recipe->getPositionEffect();
            // Rysuj dokąd idziemy
            if (pEffect.isEffective()) {
                x += pEffect.deltaX;
                y += pEffect.deltaY;
                stop.setX(startX + x * FieldView::FIELD_SIZE);
                stop.setY(startY + y * FieldView::FIELD_SIZE);
                painter->drawLine(start, stop);
                path.addRect(start.x(), start.y(), stop.x(), stop.y());
                start = stop;
                shiftText = 0;
            }
            else {
                // Oraz co wykonamy w punkcie docelowym
                QString text = QString("%1. %2").arg(counter).arg(*activitiesIter);
                path.addText(stop.x(), stop.y() + shiftText, font, text);
                painter->drawText( stop.x(), stop.y() + shiftText, text);
                shiftText += fontSize;
            }
            activitiesIter++;
            counter ++;
        }
        painter->restore();
        prepareGeometryChange();
    }

}

