
#include <QtGui>
#include "creatureview.h"
#include "fieldview.h"
#include "controller/imagemanager.h"
#include "controller/creaturemanager.h"
#include "controller/zonemanager.h"
#include "controller/recipeexecutor.h"


bool CreatureView::paintObjectiveValue = true;
bool CreatureView::paintPlannedMovesSelectedCreature = true;

CreatureView::CreatureView(QString creatureId, const QColor &color, QGraphicsObject *parent)
    : VisualElement(creatureId, color, 10, parent)
{
    setFlags(ItemIsSelectable);
    setAcceptsHoverEvents(true);
    int size = FieldView::FIELD_SIZE / 2;
    fontSize =  FieldView::FIELD_SIZE / 8;
    int l = random() % (FieldView::FIELD_SIZE - size);
    int r = random() % (FieldView::FIELD_SIZE - size);
    rectF.setRect(l, r - fontSize, size, size + fontSize);
    imageRectF.setCoords(l, r, l + size , r + size);
    // !!!!!!!!!!!!!!!!!!!!!!1
    // Włączanie i wyłączanie efektu podczas paint i razem z możliwością usuwania itemów powoduje
    // niepoprawne odwołania do pamięci ...
    // Jeżeli odwoływaliśmy się poprzez getGraphicsEffect, a nie poprzez zmienną...
    effect = new QGraphicsColorizeEffect;
    effect->setColor(color);
    effect->setEnabled(false);
    setGraphicsEffect(effect);
}

CreatureView::~CreatureView()
{
    delete effect;
}


QRectF CreatureView::boundingRect() const
{
    return rectF;
}

QPainterPath CreatureView::shape() const
{
    QPainterPath path;
    path.addRect(rectF);
    return path;
}

void CreatureView::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
{
    Q_UNUSED(widget);
    Q_UNUSED(option);

    if (option->state & QStyle::State_MouseOver) {
        if (!effect->isEnabled())
            effect->setEnabled(true);
    } else {
        if (effect->isEnabled())
            effect->setEnabled(false);
    }

    const QImage *imagePtr = NULL;
    CreatureManager *creatureManager = CreatureManager::getManager();
    const Creature *creature = creatureManager->find(getElementId());
    if (creature) {
        const Image *image = ImageManager::getManager()->find(creature->getImageId());
        if (image) {
            imagePtr = image->getImagePtr();
            if (imagePtr && imagePtr->format() == QImage::Format_Invalid) {
                qWarning() << " INVALID FORMAT FOR IMAGE " << creature->getImageId();
            }
        } else {
            qDebug() << "not found image " << creature->getImageId();
        }
    } else {
        qDebug() << "not found creature " << getElementId() << " while painting" << "[" << this << "]" ;
    }
    if (creature) {
        if (imagePtr) {
            painter->drawImage(imageRectF, *imagePtr);
        } else {
            QColor fillColor = (option->state & QStyle::State_Selected) ? color.dark(150) : color;
            if (option->state & QStyle::State_MouseOver)
                fillColor = fillColor.light(125);

            QBrush b = painter->brush();
            painter->setBrush(QBrush(fillColor.dark(option->state & QStyle::State_Sunken ? 120 : 100)));
            painter->drawEllipse(imageRectF.toRect());
            painter->setBrush(b);
        }


        if (CreatureView::paintObjectiveValue) {
            QFont font("Times", fontSize);
            font.setStyleStrategy(QFont::ForceOutline);
            painter->save();
            painter->setFont(font);
            double objVal = creatureManager->objectiveValue(*creature);
            painter->drawText( imageRectF.left(), imageRectF.top(), QString("%1").arg(objVal, 0, 'f', 2));
            painter->restore();
        }

        // Zawierający prostokąt
        if (isSelected()) {
            QPen oldPen = painter->pen();
            QPen pen = oldPen;
            pen.setWidth(1);
            pen.setStyle(Qt::DotLine);
            painter->save();
            painter->setPen(pen);
            painter->drawRect(rectF);
            painter->restore();
        }
    }
}

void CreatureView::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
{
    Q_UNUSED(event);
    emit creatureSelected (getElementId());
}

