#include <assert.h>
#include <QtGui>

#include "fieldview.h"
#include "controller/stockmanager.h"
#include "controller/articlemanager.h"


int FieldView::FIELD_SIZE = 32;

FieldView::FieldView(QString id,
                     const QColor &color,
                     QString resourcesStockId,
                     QGraphicsObject *parent)
  : VisualElement(id, color, 1, parent)
{
    rectF.setCoords(0, 0, FIELD_SIZE, FIELD_SIZE);
    resourcesId = resourcesStockId;
    //  emmiter = viewEmitter;

 //   QGraphicsColorizeEffect *effect = new QGraphicsColorizeEffect;
   // effect ->setColor("#222222");

    //    QGraphicsBlurEffect *effect = new QGraphicsBlurEffect;
    //   effect->setBlurRadius(6);
    // islandImage.invertPixels(QImage::InvertRgb);
    //setGraphicsEffect(effect);
    penFrameWidth = 1;
}


QRectF FieldView::boundingRect() const
{

   // return rectF;
        return QRectF(rectF.left() - penFrameWidth / 2, rectF.top() - penFrameWidth / 2,
                      rectF.width() + penFrameWidth, rectF.height()+ penFrameWidth);

}

QPainterPath FieldView::shape() const
{
    QPainterPath path;
    path.addRect(rectF);
    return path;
}

void FieldView::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
{
    Q_UNUSED(widget);
    Q_UNUSED(option);
//    QImage islandImage = island.copy ( pos().x(), pos().y(), rectF.width(), rectF.height() ) ;

//    if (option->state & QStyle::State_MouseOver)
//    {
//        graphicsEffect()->setEnabled(true);
//        qDebug() << "Field Effect on" ;
//    } else {

//        graphicsEffect()->setEnabled(false);
//    }
//    painter->drawImage(rectF, islandImage);


    // A teraz stos zasobów
   // if (option->state & QStyle::State_MouseOver)
   // {
        StockManager *stockManager = StockManager::getManager();
        ArticleManager *articleManager = ArticleManager::getManager ();

        const Stock *stock = stockManager->find(resourcesId);
        //double stockCapacity = stock->getCapacity();

        Stock::Articles::const_iterator b = stock->getArticles().begin();
        Stock::Articles::const_iterator e = stock->getArticles().end();
        int fieldPartSize = FIELD_SIZE / 8;

        QRect target (1, 1, fieldPartSize, fieldPartSize);
        QRectF source(0,0,128,128);

        int textX = fieldPartSize + 1;
        int textY = fieldPartSize + 1;

        QFont font("Times", fieldPartSize - 1);
        font.setStyleStrategy(QFont::ForceOutline);

        while (b != e) {

            painter->setFont(font);
            painter->save();
            painter->drawText( textX, textY, QString("%1").arg(stock->summaryQuant(b->first), 0, 'f', 2));
            painter->restore();
            const QImage *articleImage = articleManager->getImage(b->first);
            if (articleImage) {
            painter->drawImage(target, *articleImage, source);
            } else {
                qWarning() << " no image for article " << b->first;
            }
            b++;
            textY += fieldPartSize;
            target.setTop(target.top() + fieldPartSize);
            target.setBottom(target.bottom() + fieldPartSize);
            if (target.top() >= FIELD_SIZE) {
                target.setTop(0);
                target.setLeft(FIELD_SIZE/2);
                target.setRight(target.left() + fieldPartSize);
                textX = FIELD_SIZE/2+fieldPartSize+1;
            }
        }


        if ( isSelected() )
        {
            QPen oldPen = painter->pen();
            QPen pen = oldPen;
            int width = 0;
            if (option->state & QStyle::State_Selected)
                width += 2;

            pen.setWidth(penFrameWidth);
            pen.setStyle(Qt::DotLine);
            QVector<QPoint> lines;
            lines.append(QPoint(rectF.left(), rectF.top()));
            lines.append(QPoint(rectF.left(), rectF.bottom()));

            lines.append(QPoint(rectF.left(), rectF.bottom()));
            lines.append(QPoint(rectF.right(), rectF.bottom()));

            lines.append(QPoint(rectF.right(), rectF.bottom()));
            lines.append(QPoint(rectF.right(), rectF.top()));

            lines.append(QPoint(rectF.right(), rectF.top()));
            lines.append(QPoint(rectF.left(), rectF.top()));

            painter->save();
            painter->setPen(pen);
            painter->drawLines(lines);
            painter->restore();
        }

}

void FieldView::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
{
    Q_UNUSED(event);
    emit fieldSelected (getElementId());
}

