#ifndef SIMMAINWINDOW_H
#define SIMMAINWINDOW_H
#include <map>
#include <QMainWindow>
#include <QtGui/qwidget.h>
#include <QtGui/QGraphicsItem>
#include <QPushButton>
#include <QMutex>
#include <QCheckBox>
#include "controller/fieldmanager.h"
#include "controller/creaturemanager.h"
#include "controller/speciesmanager.h"
#include "controller/articlemanager.h"
#include "controller/recipeexecutor.h"
#include "controller/stockmanager.h"
#include "controller/zonemanager.h"
#include "controller/imagemanager.h"
#include "controller/parammanager.h"
#include "controller/naturalphenomena.h"
#include "emitters/viewemitter.h"
#include "activitiesinfoview.h"
#include "view.h"
#include "creatureview.h"

QT_FORWARD_DECLARE_CLASS(QGraphicsScene)
QT_FORWARD_DECLARE_CLASS(QGraphicsView)
QT_FORWARD_DECLARE_CLASS(QLabel)
QT_FORWARD_DECLARE_CLASS(QSlider)
QT_FORWARD_DECLARE_CLASS(QSplitter)
QT_FORWARD_DECLARE_CLASS(QPropertyAnimation)

namespace Ui {
class SimMainWindow;
}

class SimMainWindow : public QMainWindow
{
    Q_OBJECT
    
public:
    explicit SimMainWindow(QWidget *parent, QString database);
    ~SimMainWindow();

public slots:
    void nextDay();
    // Wizualizacja narodziń dziecięcia
    void handleCreatureAddOrChange(QString creatureId);
    void handleCreatureBorn(QString creatureId);
    // Dodanie pola do widoku
    void handleFieldAddOrChange(QString fieldId);

    // Wizualizacja ruchu
    void handleCreatureActivity(QString creatureId, QString activityId);
    // Usunięie wizualizacji osobnik
    void handleCreatureDie(QString creatureId);
    // Wizualizacja zmiany zasobow.
    void handleStockChange(QString stockId);

    // Aktualizacja globalnej informacji o zasobach (bez dat przydatności)
    void handleArticleQuantChange(QString stockId, QString articleId, double delta);

    // Obsługa zaznaczenia na widoku danego  osobnika
    void handleCreatureSelection(QString creatureId);
    // Obsługa zaznaczenia na widoku pola
    void handleFieldSelection(QString fieldId);
    void handleContextMenuRequest(QPoint point);
    void modifyFieldAtPoint();

    // Wznów/zatrzymaj timer.
    void setSimulationRun (bool run);
    void setCreaturesObjectiveValuesVisibility(bool show);
    void dayInterval(int dayInMilisecond);
    // Zapisz dane o ściecie do aktualnie używanej bazy danych
    void saveToCurrentDb();
signals:
    void stockChanged(QString stockId);
    void worldStockChanged(const Stock &stock);
private:
    Ui::SimMainWindow *ui;
    QGraphicsScene *scene;
    View *view;
    FieldManager *fieldManager;
    CreatureManager *creatureManager;
    SpeciesManager *speciesManager;
    ArticleManager *articleManager;
    RecipeExecutor *recipeExecutor;
    StockManager *stockManager;
    ZoneManager *zoneManager;
    NaturalPhenomena *naturalPhenomena;
    ImageManager *imageManager;
    ParamManager *paramManager;
    class ObjectsViews : public std::map<QString, QGraphicsObject *> {};
    CreaturesVisuals creaturesViews;
    ObjectsViews fieldsViews;
    int dayNo;
    QString lastSelectedStockId;
    QString lastSelectedCreatureId;
    void populateScene();
    void loadWorld (QString databaseFile);
    QPushButton *startStopAction;
    QTimer *stepTimer;
    ActivitiesInfoView *activitiesView;
    ActivitiesView *creatureActivitiesView;
    QPoint worldCoordinates;
    QString currentDBName;
    QMutexLocker *locker;
    QMutex *mutex;
    Stock worldStock;
    QCheckBox *animateCreatures;
};

#endif // SIMMAINWINDOW_H
