#include <QStringListModel>
#include <QDebug>
#include <QGridLayout>
#include "stockinfoview.h"
#include "controller/stockmanager.h"

StockInfoView::StockInfoView(QWidget *parent) :
    QWidget(parent)
{
    label = new QLabel(this);
    QGridLayout *gridLayout = new QGridLayout;
    tree = new QTreeWidget(this);
    QStringList labels;
    labels << "article" << "quant" << "shelfTime" ;
    tree->setHeaderLabels ( labels);
    //tree->connect(tree, SIGNAL())
    gridLayout->addWidget(label);
    gridLayout->addWidget(tree);
    setLayout(gridLayout);
}

void StockInfoView::displayStockInfo(QString stockId)
{
    tree->clear();
    label->setText("");
    const Stock *stock = StockManager::getManager()->find(stockId);
    if (stock) {
        displayStockInfo(*stock);
    }
}


void StockInfoView::displayStockInfo(const Stock &stock)
{
    label->setText(QString ("%1, used/volume: %2 / %3").arg(stock.getId()).arg(stock.volumeUsed()).arg(stock.getCapacity()));
    tree->clear();
    // QStringListModel *model = new QStringListModel(this);
    Stock::Articles::const_iterator articleIter = stock.getArticles().begin();
    Stock::Articles::const_iterator articlesEnd = stock.getArticles().end();
    QList<QTreeWidgetItem *> items;
    while (articleIter != articlesEnd) {
        Stock::ArticleQuants::const_iterator qIter = articleIter->second.begin();
        Stock::ArticleQuants::const_iterator qEnd = articleIter->second.end();
        QTreeWidgetItem *articleItem = new QTreeWidgetItem(tree);
        articleItem->setText(0, articleIter->first);
        articleItem->setText(1, QString("%1").arg(stock.summaryQuant(articleIter->first)));

        QStringList item;
        while (qIter != qEnd) {

            QTreeWidgetItem *quantsItem = new QTreeWidgetItem(articleItem);
            quantsItem->setText(1, QString ("%1").arg(qIter->quant));
            quantsItem->setText(2, QString("%1").arg(qIter->shelfTime));

            quantsItem->setFlags(quantsItem->flags() | Qt::ItemIsEditable);

            qIter ++;

        }
        items.append(articleItem);
        tree->insertTopLevelItems(0, items);
        articleIter++;
    }
}

