#include "creaturemanagertest.h"
#include "zonemanager.h"
#include "recipeexecutor.h"
#include "speciesmanager.h"

CreatureManagerTest::CreatureManagerTest() :ExampleData()
{
}

void CreatureManagerTest::setUp()
{
    ExampleData::setUp();
    // Tworzymy gatunek
    int activitiesCount = 4;
    QString backpackCapacityId = "backpack";
    Stock stock(backpackCapacityId, 100);
    stockManager->merge(stock);
    humanSpecies = new Species("humanRace", activitiesCount, backpackCapacityId);
    Coordinates coordinates(10, 10);
    human = new Creature("man", coordinates, *humanSpecies, stock);
}

void CreatureManagerTest::tearDown()
{
    ExampleData::tearDown();
    delete humanSpecies;
    delete human;
}

void CreatureManagerTest::movingTest()
{
    Zone zone("zone");
    zone.setArea(Area(0, 0, 5, 5));
    Recipe moveUpRight ("moveUpRight", Container::CREATURE);
    Recipe moveDownLeft ("moveDownLeft", Container::CREATURE);

    moveUpRight.setPositionEffect(1, 1);
    moveDownLeft.setPositionEffect(-1, -1);

    zoneManager->merge(zone);
    recipeExecutor->merge(moveUpRight);
    recipeExecutor->merge(moveDownLeft);

    QString backpackCapacityId = "it_backpack";
    Stock stock(backpackCapacityId, 100);
    stockManager->merge(stock);
    Creature it ("it", Coordinates(5, 5), *humanSpecies, stock);
    it.move(0, 0, zoneManager->getWorldArea());
    it.addActivity(moveUpRight);
    creatureManager->merge(it);
    const Creature *creature = creatureManager->find(it.getId());

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Współrzędne istoty zerują się bo 10x10 nie jest poprawną współrzędną",
                                 0,
                                 creature->getCoordinates().x());
    creatureManager->dayActivity(creature->getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Współrzędne istoty zerują zwiększyły się o 1",
                                 1,
                                 creature->getCoordinates().x());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Współrzędne istoty zerują zwiększyły się o 1",
                                 1,
                                 creature->getCoordinates().y());

    it.addActivity(moveDownLeft);
    creatureManager->merge(it);
    creature = creatureManager->find(it.getId());

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Mamy dwa niwelujące się ruchy",
                                 (int) 2,
                                 (int) creature->getActivities().size());

    creatureManager->dayActivity(creature->getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Współrzędne istoty nie zmieniły się (startujemy od zera",
                                 0,
                                 creature->getCoordinates().x());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Współrzędne istoty nie zmieniły się",
                                 0,
                                 creature->getCoordinates().y());

    it.addActivity(moveDownLeft);
    creatureManager->merge(it);
    creature = creatureManager->find(it.getId());
    creatureManager->dayActivity(creature->getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Istota idzie w dół/lewo (a startowala od 0)",
                                 zone.getArea().width() - 1,
                                 creature->getCoordinates().x());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Istota idzie w dół/lewo",
                                 zone.getArea().height() - 1,
                                 creature->getCoordinates().y());

    creatureManager->dayActivity(creature->getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Istota idzie w dół/lewo",
                                 zone.getArea().width() - 2,
                                 creature->getCoordinates().x());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Istota idzie w dół/lewo",
                                 zone.getArea().width() - 2,
                                 creature->getCoordinates().y());

}


void CreatureManagerTest::dayActivityTest()
{
   // CreatureManager *creatureManager = CreatureManager::getManager();
   // ZoneManager *zoneManager = ZoneManager::getManager();
   // zoneManager->clear();

  //  RecipeExecutor *recipeExecutor = RecipeExecutor::getManager();
   // recipeExecutor->clear();

    recipeExecutor->merge(*eatingBread);
    recipeExecutor->merge(*buyingWood);
    recipeExecutor->merge(*sowingCorn);
    recipeExecutor->merge(*moveLeft);

    CPPUNIT_ASSERT_MESSAGE("Istota na początku nie posiada zdefiniowanych aktywności",
                           human->getActivities ().size () == 0);

    human->addActivity (*eatingBread);
    CPPUNIT_ASSERT_MESSAGE("Po dodaniu aktywaności ich liczba powinna się zwiększyć",
                           human->getActivities ().size () == 1);

    creatureManager->executeActivities(*human);

    const Stock *backpack = stockManager->find(human->getBackpackId());

    CPPUNIT_ASSERT_MESSAGE("Istota nie mogła nic zjeść, bo ma pusty plecak. Zatem nie zyskała energii",
                           backpack->summaryQuant(energy->getId()) == 0);

    Stock humanBackpack(*backpack);
    humanBackpack.push(*bread, 2.0);
    stockManager->merge(humanBackpack);
    creatureManager->executeActivities(*human);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Istota zyskala 1 jednostkę energii bo mogła zjeść chleb",
                                 (double) 1,
                                 backpack->summaryQuant(energy->getId()));

    human->addActivity (*buyingWood);
    creatureManager->executeActivities(*human);
    CPPUNIT_ASSERT_MESSAGE("Istota zyskala 1 jednostkę energii bo mogła zjeść chleb, "
                           "ale nie mogła kupić drewna bo nie ma monet",
                           backpack->summaryQuant(energy->getId()) == 2.0
                           &&
                           backpack->summaryQuant(wood->getId()) == 0
                           );

    backpack = stockManager->find(humanBackpack.getId());
    humanBackpack = *backpack;
    humanBackpack.push(*coin, 10.0); // cena chleba = 5 monet
    stockManager->merge(humanBackpack);

    creatureManager->executeActivities(*human);
    CPPUNIT_ASSERT_MESSAGE("Istota nie zyskala energii bo zjadła chleb, "
                           "ale nie mogła kupić drewna, bo nie jest na żadnym polu gdzie jest sklep",
                           backpack->summaryQuant(energy->getId()) == 2.0
                           &&
                           backpack->summaryQuant(wood->getId()) == 0
                           );


    Stock fieldMarket ("aMarket");
    Stock fieldResources ("aField");

    Zone zone ("creatureField"); // , fieldResources.getId(), fieldMarket.getId()
    Area fieldArea (-10, 10, 20, 20);
    zone.setArea(fieldArea);
    fieldMarket.setCapacity(1000);
    fieldMarket.push(*wood, 3);

    Field field("aField", 10, 10);
    Market market ("aMarket", 10, 10, 2, 2);
    marketManager->merge (market);
    fieldManager->merge(field);
    zoneManager->merge(zone);
    stockManager->merge(fieldMarket);
    stockManager->merge(fieldResources);

    creatureManager->executeActivities(*human);
    CPPUNIT_ASSERT_MESSAGE("Istota kupiła 1 drewno, bo jest na polu gdzie jest sklep",
                           backpack->summaryQuant(wood->getId()) == 1
                           &&
                           backpack->summaryQuant(energy->getId()) == 2.0
                           );

    human->addActivity (*sowingCorn);
    human->addActivity (*moveLeft);

    creatureManager->executeActivities(*human);
    CPPUNIT_ASSERT_MESSAGE("Istota kupiła drugie drewno, bo miała jeszcze pieniądze",
                           backpack->summaryQuant(wood->getId()) == 2
                           &&
                           backpack->summaryQuant(coin->getId()) == 0
                           );

    CPPUNIT_ASSERT_MESSAGE("Istota poruszyła się zużywając jednostkę energii",
                           backpack->summaryQuant(energy->getId()) == 1
                           &&
                           human->getCoordinates().first == 9
                           &&
                           human->getCoordinates().second == 10
                           );

    // Jeżeli damy istocie ziarno to może je zasiac, ale nie starczy jej energii na ruch
    //  backpack = stockManager->find(humanBackpack.getId());
    humanBackpack = *backpack;
    humanBackpack.push(*corn, 1);
    stockManager->merge(humanBackpack);
    backpack = stockManager->find(humanBackpack.getId());

    creatureManager->executeActivities(*human);
    //const Zone *zone = zoneManager->find("creatureField");
    //const Stock *resources = stockManager->find(zone->getResourcesId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE ("Istota wykorzystała całą energię",
                                  (double) 0,
                                  backpack->summaryQuant(energy->getId()) );
    CPPUNIT_ASSERT_EQUAL_MESSAGE ("nie ma ziarna bo zasiała albo nie ruszyła się",
                                  (double) 0 == backpack->summaryQuant(corn->getId()),
                                  9 == human->getCoordinates().first
                                  );
    zoneManager->clear();
}

void CreatureManagerTest::matingTest()
{
    Coordinates coordinates(10, 10);
    Stock momStock ("momStock");
    Stock dadStock ("dadStock");
    Stock humanInitialStock (humanSpecies->getInitialStockId(), 10);
    stockManager->merge(momStock);
    stockManager->merge(dadStock);
    stockManager->merge(humanInitialStock);
    Creature *mom = new Creature("mam", coordinates, *humanSpecies, momStock);
    Creature *dad = new Creature("mam", coordinates, *humanSpecies, dadStock);

    mom->addActivity(*eatingBread);
    mom->addActivity(*eatingBread);
    mom->addActivity(*eatingBread);
    mom->addActivity(*buyingWood);

    dad->addActivity(*sowingCorn);
    dad->addActivity(*sowingCorn);
    dad->addActivity(*sowingCorn);
    dad->addActivity(*moveLeft);

    Creature child ("child");

    Zone zone ("creatureField");
    Area fieldArea (-10, 10, 20, 20);
    zone.setArea(fieldArea);
    ZoneManager::getManager()->merge(zone);
    humanSpecies->setMutationProbability (0.0);
    humanSpecies->setCrossoverProbability (1.0);
    SpeciesManager::getManager()->merge(*humanSpecies);

    // GODY
    CreatureManager::getManager()->mating(*mom, *dad, child);


    Zone *childField = ZoneManager::getManager()->zoneWithPoint(child.getCoordinates().first,
                                                                   child.getCoordinates().second);
    CPPUNIT_ASSERT_MESSAGE("Dziecie znajduje się na tym samym polu co rodzice",
                           childField != NULL
            &&
            childField->getId() == zone.getId());

    const Species *childSpecies = SpeciesManager::getManager()->find(child.getSpeciesId());
    CPPUNIT_ASSERT_MESSAGE("Dziecie jest tego samego gatunku",
                           childSpecies != NULL
            &&
            childSpecies->getId() == humanSpecies->getId());

    const Stock *creatureBackpack = stockManager->find(child.getBackpackId());
    const Stock *speciesInitialStock = stockManager->find(humanSpecies->getInitialStockId());
    CPPUNIT_ASSERT_MESSAGE("Dziecie ma plecak zainicjowany zgodnie z gatunkiem ",
                           creatureBackpack->getCapacity() == speciesInitialStock->getCapacity()
                           );

    Creature::Activities::const_iterator actIter = child.getActivities().begin();
    Creature::Activities::const_iterator actEnd = child.getActivities().end();

    Creature::Activities::const_iterator momActIter = mom->getActivities().begin();
    Creature::Activities::const_iterator dadActIter = dad->getActivities().begin();

    CPPUNIT_ASSERT_MESSAGE("Dziecie ma tyle samo aktywności co mama i tata",
                           child.getActivities().size() == mom->getActivities().size()
                           &&
                           child.getActivities().size() == dad->getActivities().size()

                           );

    while (actIter != actEnd) {
        QString activity = *actIter;
        QString momActivity = *momActIter;
        QString dadActivity = *dadActIter;

        CPPUNIT_ASSERT_MESSAGE("Wyłączając mutację, dziecie ma geny mamy lub taty",
                               activity == momActivity || activity == dadActivity
                               );
        actIter ++;
        momActIter++;
        dadActIter++;
    }

    delete mom;
    delete dad;
}

void CreatureManagerTest::createInAreaSelectionTest()
{
    Species dogs ("dogs", 10, "dogsInitialStock");
    Species cats ("cats", 12, "catsInitialStock");
    Zone fieldOne("fOne");
    Zone fieldTwo("fTwo");

    fieldOne.setArea(Area(-10, -10, 20, 20));
    fieldTwo.setArea(Area(1000, 1000, 10, 10));
    Stock plutoStock ("plutoStock");
    Stock tomStock ("tomStock");
    Stock garfieldStock ("garfieldStock");
    Stock dogsInitialStock(dogs.getInitialStockId(), 10);
    Stock catsInitialStock(cats.getInitialStockId(), 10);
    stockManager->merge(dogsInitialStock);
    stockManager->merge(catsInitialStock);
    stockManager->merge(plutoStock);
    stockManager->merge(tomStock);
    stockManager->merge(garfieldStock);


    Creature pluto("pluto", Coordinates(1, 1), dogs, plutoStock);
    Creature tom("tom", Coordinates(1000,1000), cats, tomStock);
    Creature garfield("garfield", Coordinates(1001,1000), cats, garfieldStock);

    CreatureManager::IdsOfObjects dogsIds =
            creatureManager->creaturesInArea(fieldOne.getArea(), dogs);

    CPPUNIT_ASSERT_MESSAGE("Na polu, które nie istnieje (nie dodano do managera) nie ma osobników",
                           dogsIds.size() == 0);

    creatureManager->merge(pluto);
    creatureManager->merge(tom);
    creatureManager->merge(garfield);

    speciesManager->merge(dogs);
    speciesManager->merge(cats);

    zoneManager->merge(fieldOne);
    zoneManager->merge(fieldTwo);

    dogsIds = creatureManager->creaturesInArea(fieldOne.getArea(), dogs);
    CreatureManager::IdsOfObjects catsIds =
            creatureManager->creaturesInArea(fieldOne.getArea(), cats);

    CPPUNIT_ASSERT_MESSAGE("Na polu fOne powinien znajdować się jeden osobnik danego gatunki i zero innych",
                           dogsIds.size() == 1
                           &&
                           catsIds.size() == 0);

    pluto.move(1001, 1001, Area (-1000, -1000, 10000, 10000));
    creatureManager->merge(pluto);

    dogsIds = creatureManager->creaturesInArea(fieldOne.getArea(), dogs);
    CPPUNIT_ASSERT_MESSAGE("Po opuszceniu obszaru pola przez jedynego osobnika jest ono puste",
                           dogsIds.size() == 0);

    dogsIds = creatureManager->creaturesInArea(fieldTwo.getArea(), dogs);
    catsIds = creatureManager->creaturesInArea(fieldTwo.getArea(), cats);

    CPPUNIT_ASSERT_MESSAGE("Wszyskie osobniki przeszły na drugie pole",
                           dogsIds.size() == 1
                           &&
                           catsIds.size() == 2
                           &&
                           dogsIds.at(0) == pluto.getId());
}

void CreatureManagerTest::reproductionTest()
{


    Species dogs ("dogs", 10, "dogsInitialStock");
    Stock dogsInitialStock(dogs.getInitialStockId(), 10);
    stockManager->merge(dogsInitialStock);

    Area area (-10, -10, 20, 20);

    Stock plutoStock ("plutoStock");
    Stock dogStock ("dogStock");
    dogs.setCrossoverProbability(1);
    dogs.setMutationProbability(0.001);

    stockManager->merge(plutoStock);
    stockManager->merge(dogStock);

    Creature pluto("pluto", Coordinates(1, 1), dogs, plutoStock);
    Creature dog ("dog", Coordinates(3,3), dogs, dogStock);
    creatureManager->merge(pluto);
    speciesManager->merge(dogs);

    creatureManager->reproduction(area, dogs);
    CPPUNIT_ASSERT_MESSAGE("Jeden osobnik nie może się rozmnożyć",
                           creatureManager->getCache().size() == 1);

    creatureManager->merge(dog);
    CPPUNIT_ASSERT_MESSAGE("Przed reprodukcją mamy dwa osobniki",
                           creatureManager->getCache().size() == 2);

    creatureManager->reproduction(area, dogs);

    CPPUNIT_ASSERT_MESSAGE("Po reprodukcji powiniśmy mieć trzy osobniki",
                           creatureManager->getCache().size() == 3);

    CreatureManager::IdsOfObjects dogsIds =
            creatureManager->creaturesInArea(area, dogs);

    CPPUNIT_ASSERT_MESSAGE("Wszystkie osobniki znajdują się w tym samym obszarze",
                           dogsIds.size() == 3);

    creatureManager->reproduction(area, dogs);

    CPPUNIT_ASSERT_MESSAGE("Po reprodukcji powiniśmy mieć 4 osobniki",
                           creatureManager->getCache().size() == 4);
    dogsIds = creatureManager->creaturesInArea(area, dogs);

    CPPUNIT_ASSERT_MESSAGE("Wszystkie osobniki znajdują się w tym samym obszarze",
                           dogsIds.size() == 4);


}

void CreatureManagerTest::objectiveValueTest()
{
    Species dogs ("dogs");

    Stock plutoStock ("plutoStock");
    stockManager->merge(plutoStock);


    Creature pluto("pluto", Coordinates(1, 1), dogs, plutoStock);
    Stock plutoBackPack ("plutoBackpack", 100);
    pluto.setBackpackId(plutoBackPack.getId());

    stockManager->merge(plutoBackPack);
    creatureManager->merge(pluto);


    CPPUNIT_ASSERT_MESSAGE("Wartość funkcji celu dla nowego osobnika jest zerowa, bo nie miał początkowego plecaka",
                           creatureManager->objectiveValue(pluto) == 0);

    plutoBackPack.push(bread->getId(), 1);
    stockManager->merge(plutoBackPack);

    CPPUNIT_ASSERT_MESSAGE("Wartość funkcji celu jest równa wartości jednego produktu posiadanego przez osobnika",
                           creatureManager->objectiveValue(pluto) == 0.5);

    plutoBackPack.push(bread->getId(), 1);
    plutoBackPack.push(coin->getId(), 1);
    plutoBackPack.push(water->getId(), 10);
    stockManager->merge(plutoBackPack);

    CPPUNIT_ASSERT_MESSAGE("Wartość funkcji celu jest równa sumie wartości produktów w plecaku",
                           creatureManager->objectiveValue(pluto) == 1.0 + 1.0 + 1.0);

}

void CreatureManagerTest::evolutionaryPressureTest()
{
    const Area area (-1, -1, 11, 11 );
    const Species species ("species");
    int creatureLimit = 8;
    CreatureManager::IdsOfObjects creaturesIds =
            creatureManager->creaturesInArea(area, species);
    CPPUNIT_ASSERT_MESSAGE("Brak osobników w obszarze",
                           creaturesIds.size() == 0);
    // Dodajemy na obszar (0,0) (10, 10) osobników 10.
    for (int i = 0; i < 10; i++) {
        Stock stock (QString ("stock %1").arg(i));
        stockManager->merge(stock);
        Creature creature(QString ("creature %1").arg(i), Coordinates(i, i), species, stock);
        creatureManager->merge(creature);
    }
    creaturesIds = creatureManager->creaturesInArea(area, species);
    CPPUNIT_ASSERT_MESSAGE("Mamy dziesięć istot",
                           creaturesIds.size() == 10);
    creatureManager->evolutionaryPressure(area, species, creatureLimit);
    creaturesIds = creatureManager->creaturesInArea(area, species);
    CPPUNIT_ASSERT_MESSAGE("Limit wynosi 8, więc liczba osobników spada do 8",
                           creaturesIds.size() == 8);

    creatureLimit = 0;
    creatureManager->evolutionaryPressure(area, species, creatureLimit);
    creaturesIds = creatureManager->creaturesInArea(area, species);
    CPPUNIT_ASSERT_MESSAGE("Limit wynosi 0, więc liczba osobników spada do 0",
                           creaturesIds.size() == 0);


}

