#include "dayinworldtest.h"

DaysInWorldTest::DaysInWorldTest() : ExampleData()
{
}

void DaysInWorldTest::setUp()
{
    ExampleData::setUp();
    Stock sf1 ("sf1", 1000.0);
    Stock sf2 ("sf2", 1000.0);
    Stock sf3 ("sf3", 1000.0);
    Stock mf1 ("mf1", 1000.0);
    Stock mf2 ("mf2", 1000.0);

    // Zasoby jakie w momencie urodzenia dostają ludzie
    Stock ihs ("ihs", 100.0);
    ihs.push(*energy, 10.0);
    // Oraz prosiaki
    Stock ips ("ips", 100.0);
    ips.push(*energy, 8.0);

    // Poszczególne zasoby osobników
    Stock h1s ("h1", 10.0);
    Stock h2s ("h2", 10.0);

    Stock p1s ("p1", 10.0);
    Stock p2s ("p2", 10.0);
    // Na swiecie znajdują się dwa gatunki osobników
    Species human("human", 4, ihs.getId());
    human.setMutationProbability(0.001);
    human.setCrossoverProbability(1);
    Species pigs ("pigs", 3, ips.getId());
    pigs.setMutationProbability(0.001);
    pigs.setCrossoverProbability(1);
    Zone::LivingCondition lc1 (human, 4, 1000, 5, 1.0);
    Zone::LivingCondition lc2 (pigs, 4, 1000, 5, 1.0);

    Phenomenon rainFall1 ("rain1", 1, *rainfall, 0, 0, 1);
    Phenomenon rainFall2 ("rain2", 1, *rainfall, 5, 4, 10, 2);

    stockManager->merge(sf1);
    stockManager->merge(sf2);
    stockManager->merge(sf3);
    stockManager->merge(mf1);
    stockManager->merge(mf2);
    stockManager->merge(ihs);
    stockManager->merge(ips);
    stockManager->merge(h1s);
    stockManager->merge(h2s);
    stockManager->merge(p1s);
    stockManager->merge(p2s);

    Field f1 (sf1.getId(), 0, 0 );
    Field f2 (sf2.getId(), 5, 4);
    Field f3 (sf3.getId(), 4, 4);
    fieldManager->merge(f1);
    fieldManager->merge(f2);
    fieldManager->merge(f3);

    // Świat składa się z dwóch sąsiadujących ze sobą pól
    Zone z1("z1"); // , sf1.getId(), mf1.getId()
    z1.setArea(Area(0,0,5,5));
    // Zjawiska natualne
    //z1.addPhenomenon(rainFall1);
    naturalPhenomena->merge(rainFall1);
    z1.addLivingCondition(lc1);
    z1.addLivingCondition(lc2);

    Zone z2("z2"); // , sf2.getId(), mf2.getId()
    z2.setArea(Area(5,0,5,5));
    z2.addLivingCondition(lc1);
    z2.addLivingCondition(lc2);
    //z2.addPhenomenon(rainFall2);
    naturalPhenomena->merge(rainFall2);
    zoneManager->merge(z1);
    zoneManager->merge(z2);

    speciesManager->merge(human);
    speciesManager->merge(pigs);

    // Tworzymy osobniki
    stockManager->copyStock (ihs.getId(), h1s.getId());
    stockManager->copyStock (ihs.getId(), h2s.getId());
    Creature h1 ("h1", Coordinates(8, 4), human, h1s);
    Creature h2 ("h2", Coordinates(4, 4), human, h2s);

    stockManager->copyStock (ips.getId(), p1s.getId());
    stockManager->copyStock (ips.getId(), p2s.getId());
    Creature p1 ("p1", Coordinates(4, 4), pigs, p1s);
    Creature p2 ("p2", Coordinates(4, 4), pigs, p2s);

    // Określamy co będą robić
    h1.addActivity(*moveLeft);
    h1.addActivity(*moveLeft);
    h1.addActivity(*moveLeft);
    h1.addActivity(*moveLeft);

    h2.addActivity(*eatingBread);
    h2.addActivity(*eatingBread);
    h2.addActivity(*eatingBread);
    h2.addActivity(*eatingBread);

    p1.addActivity(*moveLeft);
    p1.addActivity(*moveLeft);
    p1.addActivity(*moveLeft);

    p2.addActivity(*eatingBread);
    p2.addActivity(*eatingBread);
    p2.addActivity(*eatingBread);

    creatureManager->merge(h1);
    creatureManager->merge(h2);
    creatureManager->merge(p1);
    creatureManager->merge(p2);
}

void DaysInWorldTest::tearDown()
{
    ExampleData::tearDown();
}

void DaysInWorldTest::passageOfTimeTest()
{
    int dayNo = 1;

    // Wyszukaj wszystkie osobniki , które znajdują się w świecie i niech każdy
    // wykonuje swoje czynności

    // TODO : Podzielić zwracany zbiór na podzbiory i wykonywać je w wątku
    CreatureManager::Cache::const_iterator creatureIt = creatureManager->getCache().begin();
    CreatureManager::Cache::const_iterator creatureEnd = creatureManager->getCache().end();
    while (creatureIt != creatureEnd) {
        creatureManager->dayActivity(creatureIt->first);
        creatureIt++;
    }

    // Na wszystkich polach wszystkie gatunki mnożą się i umierają
    ZoneManager::Cache::const_iterator zoneIt = zoneManager->getCache().begin();
    ZoneManager::Cache::const_iterator zoneEnd = zoneManager->getCache().end();
    while (zoneIt != zoneEnd) {
        zoneManager->reproduction(zoneIt->second);
        zoneManager->evolutionaryPressure(zoneIt->second);
        zoneIt++;
    }

    // Wszystkie pola doświadczają upływu czasu
    // TODO: Każde pole może robić to w osobnym wątku
    naturalPhenomena->passageOfTime(dayNo);

    // Zaktualizuj wszystkie stany
    StockManager::Cache::const_iterator stockIt = stockManager->getCache().begin();
    StockManager::Cache::const_iterator stockEnd = stockManager->getCache().end();
    while (stockIt != stockEnd) {
        stockManager->dayPassed(stockIt->first);
        stockIt++;
    }

    const Stock *sf1 = stockManager->find("sf1");
     const Stock *sf2 = stockManager->find("sf2");
     const Stock *sf3 = stockManager->find("sf3");

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 0x0 mamy wodę w ilości 10 - wynika z definicji receptury deszczu",
                                 (double) 10.0,
                                 sf1->summaryQuant(water->getId()));
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 5x4 mamy wodę w ilości 2 "
                                 "- zasięg deszczu 2 i 10 wystąpień na raz - zatem raz się powtórzy zaczynając od 5x4",
                                 (double) 2 * rainQuantityInRecipe,
                                 sf2->summaryQuant(water->getId()));

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 4x4 mamy wodę w ilości 1 "
                                 "- zasięg deszczu 2 i 10 wystąpień na raz - zatem raz przejdzie na inną strefę",
                                 (double) 1 * rainQuantityInRecipe,
                                 sf3->summaryQuant(water->getId()));


    const Species *human = speciesManager->find("human");
    CreatureManager::IdsOfObjects humansIds = creatureManager->creaturesInArea(Area (0, 0, 5, 5),
                                                                            *human) ;

    const Creature *h1 = creatureManager->find("h1");

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Osobnik przeszedł z pola f1 na f1",
                                 4,
                                 h1->getCoordinates().first);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Powinien pojawić się dodatkowy osobnik w tym obszarze (bo dwa osobniki wydały go na świat)",
                                 (int) 3,
                                 (int) humansIds.size());

}
