#include "naturalphenomenatest.h"

NaturalPhenomenaTest::NaturalPhenomenaTest() : ExampleData ()
{
}



void NaturalPhenomenaTest::passageOfTimeTest()
{
    int dayNo = 0;
    Stock resources ("resources", 10000);
    Stock market ("market", 1000);
    recipeExecutor->merge(*rainfall);
    recipeExecutor->merge(*plantGrowth);
    stockManager->merge(resources);
    stockManager->merge(market);
    Zone zone ("forest");//, resources.getId(), market.getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Pole na starcie świat jest wolny od zjawisk",
                                 (int) 0, (int) naturalPhenomena->getCache().size());

    const Stock *fieldResources =
      stockManager->find(resources.getId());
    CPPUNIT_ASSERT_MESSAGE("Zasoby pola powinny być zerowe",
                           fieldResources->isEmpty());

    zone.setArea(Area(0,0,1,1));
    Field f (resources.getId(), 0, 0);
    Market m (market.getId(), 0, 0, 1, 1);
    fieldManager->merge(f);
    marketManager->merge(m);
    int everyTenDays = 10;
    Phenomenon phenomenonOfRainfall ("rainfall", everyTenDays, *rainfall, 0, 0, 1);
    int everyYear = 356;
    Phenomenon phenomenonOfPlantGrowth ("plantGrowth", everyYear, *plantGrowth, 0, 0);
    naturalPhenomena->merge(phenomenonOfRainfall);
    //zone.addPhenomenon(phenomenonOfRainfall);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na świecie mamy jedno zjawisko",
                                 1, (int)  naturalPhenomena->getCache().size());
    // Możemy ruszyć kołem czasu i zobaczyć czy pada deszcz.
    for (dayNo = 1; dayNo < 356; dayNo++) {
        naturalPhenomena->passageOfTime(dayNo);
        CPPUNIT_ASSERT_EQUAL_MESSAGE("Zasób pola związany z wodą powinien zwiększać się raz na X dni",
                                     (int) ( round( dayNo / phenomenonOfRainfall.frequency ) *  rainQuantityInRecipe),
                                     (int) fieldResources->summaryQuant(water->getId()));
    }

    naturalPhenomena->merge(phenomenonOfPlantGrowth);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polu mamy zjawisko opadu deszczu i wzrostu roślin",
                                 2, (int)  naturalPhenomena->getCache().size());

    // Każdego roku przybywać powinno drewna
    naturalPhenomena->passageOfTime(356);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Drewno nie powinno się pojawić, bo w strefie brak gleby i drzew",
                                 (double) 0.0,
                                 fieldResources->summaryQuant(wood->getId()));

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Wody jest tylo ile rok/10 ",
                                 (double) (356/10) * 10 /* pada co dziesięć dni 10 jednostek wody = 350*/,
                                 fieldResources->summaryQuant(water->getId()));

    // Takim trikiem aktualizujemy zawartość zasobów pola
    resources = *fieldResources;
    resources.push(*soil, 15);
    resources.push(*tree, 3);
    stockManager->merge(resources);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Mamy 15 gleby",
                                 (double) 15 ,
                                 fieldResources->summaryQuant(soil->getId()));


    CPPUNIT_ASSERT_EQUAL_MESSAGE("Oraz 3 drzewa",
                                 (double) 3 ,
                                 fieldResources->summaryQuant(tree->getId()));

    naturalPhenomena->passageOfTime(356);
    fieldResources = stockManager->find(resources.getId());
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Trzy sztuki drewna, bo były 3 drzewa i dla każdego wystarczająca ilość gleby i wody",
                                 (double) 3,
                                 fieldResources->summaryQuant(wood->getId()));
}



void NaturalPhenomenaTest::phenomenaOccurrenceTest()
{
    Stock sf_1 ("sf1", 1000.0);
    Stock sf_2 ("sf2", 1000.0);
    Stock sf_3 ("sf3", 1000.0);
    Stock sf_4 ("sf4", 1000.0);

    Stock mf1 ("mf1", 1000.0);
    Stock mf2 ("mf2", 1000.0);

    Phenomenon rainFall1 ("rainfall1", 1, *rainfall, 0, 0, 10, 1);
    Phenomenon rainFall2 ("rainfall2", 1, *rainfall, 5, 4, 10, 2);

    stockManager->merge(sf_1);
    stockManager->merge(sf_2);
    stockManager->merge(sf_3);
    stockManager->merge(sf_4);

    stockManager->merge(mf1);
    stockManager->merge(mf2);

    Field f1 (sf_1.getId(), 0, 0);
    Field f2 (sf_2.getId(), 5, 4);
    Field f3 (sf_3.getId(), 4, 4);
    Field f4 (sf_4.getId(), 5, 5);

    fieldManager->merge(f1);
    fieldManager->merge(f2);
    fieldManager->merge(f3);
    fieldManager->merge(f4);

    // Świat składa się z dwóch sąsiadujących ze sobą pól
    Zone z1("z1"); // , sf1.getId(), mf1.getId()
    z1.setArea(Area(0,0,5,5));
    // Zjawiska natualne
    naturalPhenomena->merge(rainFall1);

    Zone z2("z2"); // , sf2.getId(), mf2.getId()
    z2.setArea(Area(5,0,5,5));
    naturalPhenomena->merge(rainFall2);

    zoneManager->merge(z1);
    zoneManager->merge(z2);

    int dayNo = 1;

    // Wszystkie pola doświadczają upływu czasu
    // TODO: Każde pole może robić to w osobnym wątku
    naturalPhenomena->passageOfTime(dayNo);

    // Zaktualizuj wszystkie stany
    StockManager::Cache::const_iterator stockIt = stockManager->getCache().begin();
    StockManager::Cache::const_iterator stockEnd = stockManager->getCache().end();
    while (stockIt != stockEnd) {
        stockManager->dayPassed(stockIt->first);
        stockIt++;
    }

    const Stock *sf1 = stockManager->find("sf1");
    const Stock *sf2 = stockManager->find("sf2");
    const Stock *sf3 = stockManager->find("sf3");
    const Stock *sf4 = stockManager->find("sf4");

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 0x0 mamy wodę w ilości 10 - wynika z definicji receptury deszczu",
                                 (double) 10.0 * rainQuantityInRecipe,
                                 sf1->summaryQuant(water->getId()));
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 5x4 mamy wodę w ilości 2 "
                                 "- zasięg deszczu 2 i 10 wystąpień na raz - zatem raz się powtórzy zaczynając od 5x4",
                                 (double) 2 * rainQuantityInRecipe,
                                 sf2->summaryQuant(water->getId()));
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 4x4 mamy wodę w ilości 1 "
                                 "- zasięg deszczu 2 i 10 wystąpień na raz - zatem raz przejdzie na inną strefę",
                                 (double) 1 * rainQuantityInRecipe,
                                 sf3->summaryQuant(water->getId()));
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Na polach 5x5 mamy wodę w ilości 1 "
                                 "- zasięg deszczu 2 i 10 wystąpień na raz - zatem raz przejdzie tam gdzie stref brak",
                                 (double) 1 * rainQuantityInRecipe,
                                 sf4->summaryQuant(water->getId()));
}

