#include "recipetest.h"

RecipeTest::RecipeTest():
    CppUnit::TestCase()
{
}

void RecipeTest::setUp()
{
}

void RecipeTest::tearDown()
{
}

void RecipeTest::recipeTest()
{
    Recipe recipe ("example", Container::CREATURE);
    // Na początku recepruta jest pusta
    CPPUNIT_ASSERT(recipe.getProducts().empty());
    CPPUNIT_ASSERT(recipe.getResources().empty());
    // Receptura domyślnie nie wpływa na pozycję
    CPPUNIT_ASSERT(recipe.getPositionEffect().isEffective() == false);
    CPPUNIT_ASSERT(recipe.getRequiredContainerTypes().size() == 0);

    QString productName = "product";
    double productQuant = 0.1;
    QString resourceOneName = "resourceOne";
    double resource1Quant = 1;
    QString resourceTwoName = "resourceTwo";
    double resource2Quant = 2;

    recipe.addProduct (Container::CREATURE, productName, productQuant);
    CPPUNIT_ASSERT(recipe.getRequiredContainerTypes().size() == 1);
    recipe.addResource(Container::FIELD, resourceOneName, resource1Quant);
    recipe.addResource(Container::MARKET, resourceTwoName, resource2Quant);
    CPPUNIT_ASSERT(recipe.getRequiredContainerTypes().size() == 3);

    // Po dodaniu produktu posiada jeden produkt
    CPPUNIT_ASSERT(recipe.getProducts().size() == 1);
    // Oraz dwa surowce
    CPPUNIT_ASSERT(recipe.getResources().size() == 2);
    // Testujemy własności dodanych produktów i surowców
    Recipe::Element product = recipe.getProducts().at(0);
    CPPUNIT_ASSERT(product.articleId == productName);
    CPPUNIT_ASSERT(product.quant == productQuant);
    CPPUNIT_ASSERT(product.container == Container::CREATURE);

    Recipe::Element resource1 = recipe.getResources().at(0);
    CPPUNIT_ASSERT(resource1.articleId == resourceOneName);
    CPPUNIT_ASSERT(resource1.quant == resource1Quant);
    CPPUNIT_ASSERT(resource1.container == Container::FIELD);

    Recipe::Element resource2 = recipe.getResources().at(1);
    CPPUNIT_ASSERT(resource2.articleId == resourceTwoName);
    CPPUNIT_ASSERT(resource2.quant == resource2Quant);
    CPPUNIT_ASSERT(resource2.container == Container::MARKET);

    // Sprawdzamy czy receptura zachowuje wpływ na pozycję
    recipe.setPositionEffect (-1, 1);
    Recipe::PositionEffect positionEffect = recipe.getPositionEffect();
    CPPUNIT_ASSERT(positionEffect.isEffective());
    CPPUNIT_ASSERT(positionEffect.deltaX == -1);
    CPPUNIT_ASSERT(positionEffect.deltaY == 1);
}
