#include "stockmanagertest.h"

StockManagerTest::StockManagerTest()
{
}

void StockManagerTest::copyStockTest()
{

    // Nowo stworzony stos jest pusty i ma zerową pojemność
    Stock stock ("source", 100.0);
    Article a1 ("a1", 1.1, 11);
    Article a2 ("a2", 2.2, 22);
    Article a3 ("a3", 3.3, 33);

    ArticleManager::getManager()->merge(a1);
    ArticleManager::getManager()->merge(a2);
    ArticleManager::getManager()->merge(a3);

    stock.push(a1, 10);
    stock.push(a2, 2);
    stock.push(a3, 1);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Wykorzystanie pojemności w kopi i oryginale powinno być takie samo",
                                 a1.volume(10) + a2.volume(2) + a3.volume(1),
                                 stock.volumeUsed());
    QString destId ("dest");
    stockManager->merge(stock);
    stockManager->copyStock(stock.getId(), destId);
    const Stock *copyOfStock = stockManager->find(destId);

    bool copied = copyOfStock != NULL;

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Kopia  powinna się udać, i możemy ją znaleźć w managerze",
                                 true,
                                 copied);

    if (copied) {
        CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Wykorzystanie jest identyczne",
                                             stock.volumeUsed(),
                                             copyOfStock->volumeUsed(), 0);

        CPPUNIT_ASSERT_EQUAL_MESSAGE("Wybrany artykuł tyle samo zajmuje",
                                     copyOfStock->summaryQuant(a2.getId()),
                                     stock.summaryQuant(a2.getId()));
    }
}

void StockManagerTest::moveStockTest()
{
    //stockManager->clear();
    // Nowo stworzony stos jest pusty i ma zerową pojemność
    Stock stock ("source", 100.0);
    Article a1 ("a1", 1.1, 11);
    Article a2 ("a2", 2.2, 22);
    Article a3 ("a3", 3.3, 33);

    ArticleManager::getManager()->merge(a1);
    ArticleManager::getManager()->merge(a2);
    ArticleManager::getManager()->merge(a3);

    stock.push(a1, 10);
    stock.push(a2, 20);
    stock.push(a3, 3);
    double vUsed = stock.volumeUsed();
    Stock dest("dest", 100.0);
    stockManager->merge(stock);
    stockManager->merge(dest);

    bool moved = stockManager->moveContent(stock.getId(), dest.getId());
    const Stock *destStock = stockManager->find(dest.getId());
    const Stock *srcStock = stockManager->find(stock.getId());

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Przeniesienie powinno się udać",
                                 true,
                                 moved);

    CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("W źródle nic nie zostało",
                                         0,
                                         srcStock->volumeUsed(), 0.00001);

    CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Cel zajęty tak samo jak źródło początkowo",
                                         vUsed,
                                         destStock->volumeUsed(), 0.00001);

    // TERAZ DEST BĘDZIE ŹRÓDŁEM
    Stock small("small", 4.0);
    stockManager->merge(small);
    moved = stockManager->moveContent(dest.getId(), small.getId(), false);
    const Stock *smallStock = stockManager->find(small.getId());

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Przeniesienie nie powinno się udać do za małego zasobnika",
                                 false,
                                 moved);
    CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("W źródle zostało wszystko",
                                         vUsed,
                                         destStock->volumeUsed(), 0.00001);
    CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("W celu nie ma nic",
                                         0,
                                         smallStock->volumeUsed(), 0.00001);

    moved = stockManager->moveContent(dest.getId(), small.getId(), true);


    CPPUNIT_ASSERT_EQUAL_MESSAGE("Przeniesienie powinno się udać częściowo",
                                 true,
                                 moved);
    CPPUNIT_ASSERT_MESSAGE("W źródle coś zostało",
                           0 != destStock->volumeUsed());
    CPPUNIT_ASSERT_MESSAGE("W celu jest część",
                           9 != smallStock->volumeUsed());

}

