#include "zonemanagertest.h"

ZoneManagerTest::ZoneManagerTest()
{
}

void ZoneManagerTest::setUp()
{
    ExampleData::setUp();
}

void ZoneManagerTest::tearDown()
{
    ExampleData::tearDown();
}


void ZoneManagerTest::findingZonesTest()
{
    // Dodajemy pola
    Zone f_m2xm2_4x4 ("squere_m2_m2_4_4");
    Area area1 (-2, -2, 4, 4);
    f_m2xm2_4x4.setArea(area1);

    Zone f_4x4_10x10 ("squere_4_4_10_10");
    Area area2 (4, 4, 10, 10);
    f_4x4_10x10.setArea(area2);

    Zone f_20x10_20x10 ("squere_20_0_20_10");
    Area area3 (20, 10, 10, 10);
    f_20x10_20x10.setArea(area3);

    int x;
    int y;
    for ( x = -2; x <= 2; x++) {
        for ( y = -2; y <= 2; y++) {
            CPPUNIT_ASSERT_EQUAL_MESSAGE("Jeżeli pola nie są zdefiniowane, to nie znajdujemy pola z dowolnym punktem",
                                         (Zone *) NULL,
                                         zoneManager->zoneWithPoint(x, y));

        }
    }


    zoneManager->merge(f_m2xm2_4x4);
    zoneManager->merge(f_4x4_10x10);
    zoneManager->merge(f_20x10_20x10);

    testPointsInField (area1, f_m2xm2_4x4, "Wszystkie punkty z obszaru należą do pola f_m2xm2_4x4");
    testPointsInField (area2, f_4x4_10x10, "Wszystkie punkty z obszaru należą do pola f_4x4_10x10");
    testPointsInField (area3, f_20x10_20x10, "Wszystkie punkty z obszaru należą do pola f_20x10_20x10");

}

void ZoneManagerTest::worldAreaActualizationTest()
{
    CPPUNIT_ASSERT_MESSAGE("Świat na początku ma rozmiar zerowy",
                           zoneManager->getWorldArea().coordinates.first == 0
                           &&
                           zoneManager->getWorldArea().coordinates.second == 0
                           &&
                           zoneManager->getWorldArea().size.first == 0
                           &&
                           zoneManager->getWorldArea().size.second == 0
                           );

    // Dodajemy pola
    Zone f_m2xm2_4x4 ("squere_m2_m2_4_4");
    Area area1 (-2, -2, 4, 4);
    f_m2xm2_4x4.setArea(area1);
    zoneManager->merge(f_m2xm2_4x4);
    CPPUNIT_ASSERT_MESSAGE("Po dodaniu jednego pola świat przyjmuje rozmiar pola",
                           zoneManager->getWorldArea().coordinates.first == -2
                           &&
                           zoneManager->getWorldArea().coordinates.second == -2
                           &&
                           zoneManager->getWorldArea().size.first == 4
                           &&
                           zoneManager->getWorldArea().size.second == 4
                           );

    Zone f_4x4_10x10 ("squere_4_4_10_10");
    Area area2 (4, 4, 10, 10);
    f_4x4_10x10.setArea(area2);
    zoneManager->merge(f_4x4_10x10);
    CPPUNIT_ASSERT_MESSAGE("Dostosowanie się do rozmiarów sumy pól (dwóch)",
                           zoneManager->getWorldArea().coordinates.first == -2
                           &&
                           zoneManager->getWorldArea().coordinates.second == -2
                           &&
                           zoneManager->getWorldArea().size.first == 16
                           &&
                           zoneManager->getWorldArea().size.second == 16
                           );

    Zone f_20x10_20x10 ("squere_20_0_20_10");
    Area area3 (20, 10, 10, 10);
    f_20x10_20x10.setArea(area3);
    zoneManager->merge(f_20x10_20x10);

    CPPUNIT_ASSERT_MESSAGE("Dostosowanie się do rozmiarów sumy pól (trzech)",
                           zoneManager->getWorldArea().coordinates.first == -2
                           &&
                           zoneManager->getWorldArea().coordinates.second == -2
                           &&
                           zoneManager->getWorldArea().size.first == 32
                           &&
                           zoneManager->getWorldArea().size.second == 22
                           );

    Zone f_m20x10_20x10 ("squere_");
    Area area4 (-20, -20, 0, 0);
    f_m20x10_20x10.setArea(area4);
    zoneManager->merge(f_m20x10_20x10);

    CPPUNIT_ASSERT_MESSAGE("Dodanie pola o zerowych rozmiarach nie zmienia obszaru świata",
                           zoneManager->getWorldArea().coordinates.first == -2
                           &&
                           zoneManager->getWorldArea().coordinates.second == -2
                           &&
                           zoneManager->getWorldArea().size.first == 32
                           &&
                           zoneManager->getWorldArea().size.second == 22
                           );


    Zone lastF ("squere_l");
    Area area5 (-20, -20, 2, 2);
    lastF.setArea(area5);
    zoneManager->merge(lastF);

    CPPUNIT_ASSERT_MESSAGE("Zmiana początku i rozmiarów świata",
                           zoneManager->getWorldArea().coordinates.first == -20
                           &&
                           zoneManager->getWorldArea().coordinates.second == -20
                           &&
                           zoneManager->getWorldArea().size.first == 50
                           &&
                           zoneManager->getWorldArea().size.second == 40
                           );

}


void ZoneManagerTest::testPointsInField(Area &area, Zone &field, QString message)
{
    int x;
    int y;

    for (x = area.coordinates.first; x < area.coordinates.first + area.size.first; x++) {
        for (y = area.coordinates.second; y < area.coordinates.second + area.size.second; y++) {
            QString idFound ("_nie_znaleziono_");
            Zone *fieldFound = zoneManager->zoneWithPoint(x, y);
            if (fieldFound != NULL)
                idFound = fieldFound->getId();
            CPPUNIT_ASSERT_MESSAGE(message.toStdString().c_str(),
                                   field.getId() == idFound);
        }
    }
}


void ZoneManagerTest::fieldCreaturesReproductionTest()
{
    Species dogs ("dogs", 16, "dogs_init_stock");
    Species fleas ("fleas", 16, "fleas_init_stock");
    Stock dogsInitialStock (dogs.getInitialStockId(), 10);
    Stock fleasInitialStock (fleas.getInitialStockId(), 10);
    stockManager->merge(dogsInitialStock);
    stockManager->merge(fleasInitialStock);
    dogs.setCrossoverProbability(1);
    fleas.setCrossoverProbability(1);
    dogs.setMutationProbability(0.001);
    fleas.setMutationProbability(0.001);

    speciesManager->merge(dogs);
    speciesManager->merge(fleas);

    unsigned dogsLimit = 10000;
    unsigned creaturesLimitGridSize = 10000;
    unsigned fleasLimit = 10000;

    unsigned dogsMateGridSize  = 100;
    unsigned fleasMateGridSize  = 5;
    unsigned fleasPerDog = 30;
    unsigned dogsCount = 13;
    unsigned dogsInFleasGrid = 5;
    unsigned reproductionAreaCount = 3;

    Zone::LivingCondition dogsLivingCondition (dogs, dogsLimit, creaturesLimitGridSize, dogsMateGridSize, 1);
    Zone::LivingCondition fleasLivingCondition (fleas, fleasLimit, creaturesLimitGridSize, fleasMateGridSize, 1);

    Zone field ("field");
    field.addLivingCondition (dogsLivingCondition);
    field.addLivingCondition (fleasLivingCondition);

    Area fieldArea(0, 0, 30, 20);
    field.setArea(fieldArea);

    // Dodajemy na obszar (0,0) (20, 10) osobników dogsCount.
    for (unsigned i = 0; i < dogsCount; i++) {
        Stock dogStock (QString ("pluto %1 stock").arg(i));
        stockManager->merge(dogStock);
        Creature dog(QString ("pluto %1").arg(i), Coordinates(i, i / 2), dogs, dogStock);
        creatureManager->merge(dog);
        // A na każdym psie siedzieć może fleasPerDog pcheł
        for (unsigned j = 0; j < fleasPerDog; j++) {
            Stock fleaStock (QString ("flea %1 %2 stock").arg(i).arg(j));
            stockManager->merge(fleaStock);
            Creature flea(QString ("flea %1 %2").arg(i).arg(j), Coordinates(i, i / 2), fleas, fleaStock);
            creatureManager->merge(flea);
        }
    }

    CreatureManager::IdsOfObjects dogsIds = creatureManager->creaturesInArea(fieldArea, dogs);
    CreatureManager::IdsOfObjects fleasIds = creatureManager->creaturesInArea(fieldArea, fleas);

    CPPUNIT_ASSERT_MESSAGE("Na starcie na całym polu mamy dogsCount psów i dogsCount*fleasPerDog pcheł",
                           dogsIds.size() == dogsCount
                           &&
                           fleasIds.size() == dogsCount * fleasPerDog);

    Area subArea (0, 0, 20, 10);
    dogsIds = creatureManager->creaturesInArea(subArea, dogs);
    fleasIds = creatureManager->creaturesInArea(subArea, fleas);

    CPPUNIT_ASSERT_MESSAGE("dogsCount psów i dogsCount*fleasPerDog pcheł znajduje się w podobszarze większego pola",
                           dogsIds.size() == dogsCount
                           &&
                           fleasIds.size() == dogsCount * fleasPerDog);

    Area gridArea (0, 0, 9, 5);
    fleasIds = creatureManager->creaturesInArea(gridArea, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Badamy podobszar 0 - zawierający dwa obszary rozrodcze pcheł",
                                 (int) (2 * dogsInFleasGrid * fleasPerDog),
                                 (int) (fleasIds.size()) );

   Area gridArea0 (0, 0, 4, 4);
   fleasIds = creatureManager->creaturesInArea(gridArea0, fleas);
   CPPUNIT_ASSERT_EQUAL_MESSAGE("W obszarze rozrodczym jest 5 * fleasPerDog pcheł",
                               (int) (dogsInFleasGrid * fleasPerDog) ,
                               (int) (fleasIds.size()) );

    zoneManager->reproduction(field);

    fleasIds = creatureManager->creaturesInArea(gridArea0, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("W obszarze rozrodczym jest 5 * fleasPerDog + 1 pcheł",
                                (int) (dogsInFleasGrid * fleasPerDog) + 1 ,
                                (int) (fleasIds.size()) );

    Area gridArea1 (5, 0, 9, 4);
    fleasIds = creatureManager->creaturesInArea(gridArea1, fleas);

    // fleasIds = creatureManager->creaturesInArea(fieldArea, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("W drugim obszarze jest tyle samo",
                                 (int) (dogsInFleasGrid * fleasPerDog) + 1 ,
                                 (int) (fleasIds.size()) );


    dogsIds = creatureManager->creaturesInArea(fieldArea, dogs);
    fleasIds = creatureManager->creaturesInArea(fieldArea, fleas);

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Grid dla psów jest większy niż pole zatem przybył 1 pies",
                                 (int) (dogsCount + 1) ,
                                 (int) (dogsIds.size()) );

    CPPUNIT_ASSERT_EQUAL_MESSAGE("Pcheł mamy o 4 więcej bo podobszarów zdolnych do reprodukcji było 4",
                                 (int) (dogsInFleasGrid * ( reproductionAreaCount - 1) * fleasPerDog
                                        + (dogsCount - dogsInFleasGrid * ( reproductionAreaCount - 1) ) * fleasPerDog
                                        + reproductionAreaCount) ,
                                 (int) (fleasIds.size()) );

}


void ZoneManagerTest::fieldEvolutionaryPressureTest()
{

    Species dogs ("dogs", 16, "dogs_init_stock");
    Species fleas ("fleas", 16, "fleas_init_stock");
    Stock dogsInitialStock (dogs.getInitialStockId(), 10);
    Stock fleasInitialStock (fleas.getInitialStockId(), 10);
    stockManager->merge(dogsInitialStock);
    stockManager->merge(fleasInitialStock);

    speciesManager->merge(dogs);
    speciesManager->merge(fleas);

    unsigned dogsLimit = 3;
    unsigned creaturesLimitGridSize = 10;
    unsigned fleasLimit = 100;
    unsigned dogsMateGridSize  = 100;
    unsigned fleasMateGridSize  = 10;
    unsigned fleasPerDog =112;

    Zone::LivingCondition dogsLivingCondition (dogs, dogsLimit, creaturesLimitGridSize, dogsMateGridSize, 1);
    Zone::LivingCondition fleasLivingCondition (fleas, fleasLimit, creaturesLimitGridSize, fleasMateGridSize, 1);

    Zone field ("field");
    field.addLivingCondition (dogsLivingCondition);
    field.addLivingCondition (fleasLivingCondition);

    Area fieldArea(0, 0, 30, 20);
    field.setArea(fieldArea);

    // Dodajemy na obszar (0,0) (20, 10) osobników 20.
    for (unsigned i = 0; i < 20; i++) {
        Stock dogStock (QString ("pluto %1 stock").arg(i));
        stockManager->merge(dogStock);
        Creature dog(QString ("pluto %1").arg(i), Coordinates(i, i / 2), dogs, dogStock);

        creatureManager->merge(dog);
        // A na każdym psie siedzieć może fleasPerDog pcheł
        for (unsigned j = 0; j < fleasPerDog; j++) {
            Stock fleaStock (QString ("flea %1 %2 stock").arg(i).arg(j));
            stockManager->merge(fleaStock);
            Creature flea(QString ("flea %1 %2").arg(i).arg(j), Coordinates(i, i / 2), fleas, fleaStock);
            creatureManager->merge(flea);
        }
    }

    CreatureManager::IdsOfObjects dogsIds = creatureManager->creaturesInArea(fieldArea, dogs);
    CreatureManager::IdsOfObjects fleasIds = creatureManager->creaturesInArea(fieldArea, fleas);

    CPPUNIT_ASSERT_MESSAGE("Na starcie na całym polu mamy 20 psów i 20*fleasPerDog pcheł",
                           dogsIds.size() == 20
                           &&
                           fleasIds.size() == 20 * fleasPerDog);

    Area subArea (0, 0, 20, 10);
    dogsIds = creatureManager->creaturesInArea(subArea, dogs);
    fleasIds = creatureManager->creaturesInArea(subArea, fleas);

    CPPUNIT_ASSERT_MESSAGE("20 psów i 20*fleasPerDog pcheł znajduje się w podobszarze większego pola",
                           dogsIds.size() == 20
                           &&
                           fleasIds.size() == 20 * fleasPerDog);



    Area gridArea (0, 0, 9, 9);
    fleasIds = creatureManager->creaturesInArea(gridArea, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Badamy podobszar 0",
                                 (int) (10 * fleasPerDog),
                                 (int) (fleasIds.size()) );

    Area gridArea1 (10, 0, 19, 9);
    fleasIds = creatureManager->creaturesInArea(gridArea1, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE("Badamy podobszar 1",
                                 (int) (10 * fleasPerDog),
                                 (int) (fleasIds.size()) );

    zoneManager->evolutionaryPressure(field);

    dogsIds = creatureManager->creaturesInArea(fieldArea, dogs);
    fleasIds = creatureManager->creaturesInArea(fieldArea, fleas);
    CPPUNIT_ASSERT_EQUAL_MESSAGE ("Na całym polu powinno zostać 2 obszary * 3 psy",
                                  (int) (2 * dogsLimit),
                                  (int) (dogsIds.size())
                                  );
    CPPUNIT_ASSERT_EQUAL_MESSAGE ("Na całym polu powinno zostać  2*100 pcheł",
                                  (int) (2 * fleasLimit),
                                  (int) (fleasIds.size()));

    dogsIds = creatureManager->creaturesInArea(subArea, dogs);
    fleasIds = creatureManager->creaturesInArea(subArea, fleas);
    CPPUNIT_ASSERT_MESSAGE("Na wybranym podobszarze powinno zostać 2*3 psy i 2*100 pcheł",
                           dogsIds.size() == 2 * dogsLimit
                           &&
                           fleasIds.size() == 2 * fleasLimit);

    dogsIds = creatureManager->creaturesInArea(gridArea, dogs);
    fleasIds = creatureManager->creaturesInArea(gridArea, fleas);
    CPPUNIT_ASSERT_MESSAGE("Na jednej siatce grida powinno zostać 3 psy i 100 pcheł",
                           dogsIds.size() == dogsLimit
                           &&
                           fleasIds.size() == fleasLimit);
}
